(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    107589,       2460]
NotebookOptionsPosition[    102192,       2380]
NotebookOutlinePosition[    102767,       2401]
CellTagsIndexPosition[    102724,       2398]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"442974ec-4c9e-45c9-ba2e-af4f9ea01dbf"],

Cell["Chapter 7, Section 7.9, Figure 7.12", "Section",
 CellChangeTimes->{{3.870329247872877*^9, 
  3.870329248462716*^9}},ExpressionUUID->"4c583ca5-29ab-42df-b722-\
130c8619e95e"],

Cell[TextData[{
 "We start by defining ",
 StyleBox["laplace", "Input"],
 ", a procedure to calculate a Laplace coefficient by evaluating an integral \
(see Eq.(6.67))."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"23a1f66f-3303-412c-995e-0cd8bd4183f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"laplace", "[", " ", 
    RowBox[{"s_", ",", " ", "jj_", ",", " ", "aa_"}], " ", "]"}], " ", ":=", 
   " ", "\n", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"aa", " ", "!=", " ", "0"}], ",", "\n", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"N", "[", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "/", "Pi"}], ")"}], "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Cos", "[", 
            RowBox[{"jj", "*", "x"}], "]"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", "aa", "*", 
               RowBox[{"Cos", "[", "x", "]"}]}], "+", 
              RowBox[{"aa", "^", "2"}]}], ")"}], "^", "s"}], ")"}]}]}], " ", 
        "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", " ", "0", ",", " ", "Pi"}], "}"}]}], " ", "]"}], 
     ",", "0"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.869289808475835*^9, 3.869289852461238*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"109a3ed6-d326-45f6-9afe-a78fe02017d1"],

Cell[TextData[{
 "Now we define a function ",
 StyleBox["BrouwerbigAA", "Input"],
 ", a slightly shorter version of the function ",
 StyleBox["Brouwer", "Input"],
 " from ",
 StyleBox["Sect.7.8.nb",
  FontWeight->"Bold"],
 ", that returns the free precession rate for the value ",
 StyleBox["atest", "Input"],
 " of the test particle's semi-major axis.  "
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2b3480b4-09f3-4ff8-ab9e-88093ccdc961"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BrouwerbigAA", "[", 
    RowBox[{"atest_", ",", " ", "year_"}], "]"}], " ", ":=", "\n", 
   RowBox[{"Module", "[", "\n", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"m", " ", "=", " ", 
        RowBox[{"1", "/", 
         RowBox[{"{", 
          RowBox[{
          "6025607.0", ",", " ", "408662.0", ",", " ", "328912.0", ",", " ", 
           "3099774.0", ",", " ", "1047.91", ",", "\n", "         ", 
           "3500.05", ",", " ", "22970.0", ",", " ", "19360.0"}], "}"}]}]}], 
       ",", "\n", "  ", 
       RowBox[{"a", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
         "0.38710", ",", " ", "0.72333", ",", " ", "1.00002", ",", " ", 
          "1.52364", ",", " ", "5.20248", ",", "\n", "       ", "9.56329", 
          ",", " ", "19.29373", ",", " ", "30.27435"}], "}"}]}], ",", "\n", 
       "  ", 
       RowBox[{"g", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
         "5.46326", ",", " ", "7.34474", ",", " ", "17.32832", ",", " ", 
          "18.00233", ",", " ", "4.29591", ",", "\n", "       ", "27.77406", 
          ",", " ", "2.71931", ",", " ", "0.63332", ",", " ", 
          RowBox[{"-", "19.18225"}], ",", " ", "51.25222"}], "}"}]}], ",", 
       "\n", "  ", 
       RowBox[{"f", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5.21054"}], ",", " ", 
          RowBox[{"-", "6.57080"}], ",", " ", 
          RowBox[{"-", "18.74359"}], ",", " ", 
          RowBox[{"-", "17.63331"}], ",", " ", "\n", "       ", "0.00000", 
          ",", " ", 
          RowBox[{"-", "25.73355"}], ",", " ", 
          RowBox[{"-", "2.90266"}], ",", " ", 
          RowBox[{"-", "0.67752"}]}], "}"}]}], ",", "\n", "   ", 
       RowBox[{"ntest", "=", 
        RowBox[{"360.", "/", 
         RowBox[{"atest", "^", 
          RowBox[{"(", 
           RowBox[{"3", "/", "2"}], ")"}]}]}]}]}], "\n", "}"}], ",", "\n", 
     RowBox[{
      RowBox[{"tg", " ", "=", " ", "g"}], ";", " ", 
      RowBox[{"tf", " ", "=", " ", "f"}], ";", " ", 
      RowBox[{"tb", " ", "=", " ", "beta"}], ";", " ", 
      RowBox[{"tga", " ", "=", " ", "gamma"}], ";", "\n", 
      RowBox[{"gr", " ", "=", " ", 
       RowBox[{"N", "[", 
        RowBox[{"g", " ", "Degree"}], "]"}]}], ";", "\n", 
      RowBox[{"fr", " ", "=", " ", 
       RowBox[{"N", "[", 
        RowBox[{"f", " ", "Degree"}], "]"}]}], ";", "\n", 
      RowBox[{"time", " ", "=", " ", 
       RowBox[{"year", "-", "1900."}]}], ";", "\n", 
      RowBox[{"alphaj", "    ", "=", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"atest", "/", "a"}], " ", "/.", " ", 
         RowBox[{"{", 
          RowBox[{"x_", " ", ":>", " ", 
           RowBox[{
            RowBox[{"1", "/", "x"}], " ", "/;", " ", 
            RowBox[{"x", ">", "1"}]}]}], "}"}]}], ")"}]}], ";", "\n", 
      RowBox[{"alphabarj", " ", "=", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"atest", "/", "a"}], " ", "/.", " ", 
         RowBox[{"{", 
          RowBox[{"x_", " ", ":>", " ", 
           RowBox[{"1", "   ", "/;", " ", 
            RowBox[{"x", ">", "1"}]}]}], "}"}]}], ")"}]}], ";", "\n", 
      RowBox[{"b321", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"laplace", "[", 
           RowBox[{
            RowBox[{"3", "/", "2"}], ",", " ", "1", ",", " ", "#"}], "]"}], 
          "&"}], ",", " ", "alphaj"}], "]"}]}], ";", "\n", 
      RowBox[{"bigAA", " ", "=", "  ", 
       RowBox[{"ntest", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "4"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"Plus", " ", "@@", " ", 
            RowBox[{"(", 
             RowBox[{"m", "*", "alphaj", "*", "alphabarj", "*", "b321"}], 
             ")"}]}], ")"}]}], ")"}]}]}], ";", "\n", 
      RowBox[{"asbigAA", " ", "=", " ", 
       RowBox[{"bigAA", "*", "60", "*", "60"}]}], ";", "\n", 
      RowBox[{"N", "[", 
       RowBox[{"{", 
        RowBox[{"atest", ",", " ", "asbigAA"}], "}"}], "]"}]}]}], "\n", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.869289894981162*^9, 3.86928989498631*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"2989f186-9c3a-43ae-99a0-2a1ab1b17c59"],

Cell["\<\
Set the secular eigenfrequencies of the Brouwer and van Woerkom system.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"833daf2b-3d5a-4992-91e2-b97366f85591"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gg", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "5.46326", ",", " ", "7.34474", ",", " ", "17.32832", ",", " ", 
     "18.00233", ",", " ", "4.29591", ",", "\n", "       ", "27.77406", ",", 
     " ", "2.71931", ",", " ", "0.63332", ",", " ", 
     RowBox[{"-", "19.18225"}], ",", " ", "51.25222"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"ff", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5.21054"}], ",", " ", 
     RowBox[{"-", "6.57080"}], ",", " ", 
     RowBox[{"-", "18.74359"}], ",", " ", 
     RowBox[{"-", "17.63331"}], ",", " ", "\n", "       ", "0.00000", ",", 
     " ", 
     RowBox[{"-", "25.73355"}], ",", " ", 
     RowBox[{"-", "2.90266"}], ",", " ", 
     RowBox[{"-", "0.67752"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.869290025090077*^9, 3.8692900250983562`*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"289382b8-ccb6-4ca0-9300-e3b8a56a0ced"],

Cell["Set up the various annotations for the plots.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8693048318999643`*^9, 3.869304836460154*^9}, {
  3.8693048934467907`*^9, 3.86930490532615*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f62e59a8-5418-412b-a8ad-c0d1bc27f02c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"avalues", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.38710", ",", " ", "0.72333", ",", " ", "1.00002", ",", " ", "1.52364", 
     ",", " ", "5.20248", ",", "\n", "       ", "9.56329", ",", " ", 
     "19.29373", ",", " ", "30.27435"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aouter", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"avalues", ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "8"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pnameout", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<J\>\"", ",", "\"\<S\>\"", ",", "\"\<U\>\"", ",", "\"\<N\>\""}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"paouter", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"aouter", ",", "pnameout"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"linesout", "=", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", "0.004", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "12"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "60"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"60", "-", "2"}]}], "}"}]}], "}"}], "]"}], "&"}], ",", 
        "paouter"}], "]"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{"60", "-", "3"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "&"}], ",", "paouter"}], 
       "]"}]}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ainner", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"avalues", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pnamein", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<M\>\"", ",", "\"\<V\>\"", ",", "\"\<E\>\"", ",", "\"\<M\>\""}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"painner", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"ainner", ",", "pnamein"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"linesin", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", "0.004", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "12"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "60"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"60", "-", "2"}]}], "}"}]}], "}"}], "]"}], "&"}], ",", 
        "painner"}], "]"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{"60", "-", "3"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "&"}], ",", "painner"}], 
       "]"}]}], "}"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8692948802354183`*^9, 3.869294889804311*^9}, 
   3.869294923463685*^9, {3.8692949775852203`*^9, 3.86929499883803*^9}, {
   3.869295191558587*^9, 3.869295218001656*^9}, {3.869295387921208*^9, 
   3.869295388864544*^9}, {3.8692955186307383`*^9, 3.869295545841392*^9}, {
   3.86929624185314*^9, 3.869296245436421*^9}, 3.869296305242774*^9, {
   3.8692991810978823`*^9, 3.869299184394566*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"0c55eb8d-daaf-4c66-984c-7c9a6e23e2fb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<Semi-major Axis (AU)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "ylabel", "=", 
   "\"\<Precession Rate (\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
SuperscriptBox[\"\[Null]\", \"\[Prime]\[Prime]\"], TraditionalForm], \"errors\
\" -> {}, \"input\" -> \"''\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)/y)\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.869289947761011*^9, 3.869289969581517*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"f2b78f0b-e3bd-4a65-9648-dcf6de6a2893"],

Cell["\<\
Consider the inner part of the solar system.  Calculate the free precession \
rate between 0.1 and 4 AU for epoch 1997.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869304506590699*^9, 3.869304508464637*^9}, {
  3.869305000232093*^9, 3.869305004401952*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"faf53744-1524-4491-862a-40ad8ebaf6ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"precessinner", " ", "=", " ", "\n", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"BrouwerbigAA", "[", 
      RowBox[{"avalue", ",", " ", "1997"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"avalue", ",", " ", "0.1", ",", " ", "4", ",", " ", "0.01"}], 
      "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8692900730146427`*^9, 3.8692900730196247`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"e6fddd57-b9ce-462e-af5b-bb1ea51d7d85"],

Cell["Plot the rate as a function of semi-major axis.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"40d611ae-cfdb-440a-8da0-66352d0283e2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pin", " ", "=", " ", "\n", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"precessinner", ",", " ", 
    RowBox[{"Joined", "->", "True"}], ",", " ", "\n", 
    RowBox[{"Frame", "->", "True"}], ",", " ", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "60"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", "ylabel"}], "}"}]}], ",", 
    RowBox[{"RotateLabel", "->", "False"}], ",", 
    RowBox[{"AxesOrigin", "->", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"FrameTicks", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "20", ",", "40", ",", "60", ",", "80"}], "}"}], 
         ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
         "None"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
    RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.869289553461246*^9, 3.8692895679126*^9}, {
  3.869289636491899*^9, 3.8692896461218967`*^9}, {3.869289693658675*^9, 
  3.8692896960718*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"21e982c4-4262-4ab0-8239-60d9a14424a1"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQPWsmCOy07zFTVCx+/9heM6b/0FeNPfZrJty9KKr3
3H6nXOvrwB377H9d3t7Av/SV/ZICW67riw/Y+/Ws2sEe/s7+TeAOoIqD9h4d
Qt0HlT/amxiDwGF76UVKGxttP9tXi6xzf1h1xP7H9TtCs6u/2h/+qgG04ag9
Z/XdW7MefrcHGgY08bj9vweLqj8W/7IPAhkXeMJ+cqnKUgOLv/YQ9520/8GW
vmuDFIPDoyqQgafsPz6wfmm3i9EB4t4z9qdNrFj6G5gdCkHOKzhrvyiN455V
KasDxP3n7C+FN3imLWJ3YACDC/YLHPcW3RPlcoD454L91O0bdt55xOPg8RBk
wUX7L6UtbQVCAg4Q/1201zgiv92OSchhwiGQBy7Z850tP3o/XsQB4t/L9h9X
it6+HSPuAPbO9cv2yXWlOeU+0g4Q/1+x/3f/tcznRAUHeZBz5K7ay3MvW9BT
pOIANu7QVXvzZDvdpYLaDmlgcM3e7843t2krjR0g4XPdvrfz6O2sXQ4OzRd1
OC/nXLeH+MPPAQC/QtIu
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQfTBxdUO/yi17BjDwc7Djur64wPaW/eqKw8c50twd
HlWJrHN/eMs+w60rkdXPyqHtdeAOudbb9j3vcw80rjFy0IrpP/RV4479P/Hw
fqVCPYdzZ0Dgjr1Gw7rv28W0HQpsQQbetb//fbPbsU5NB5BpVSL37Ld1M0RG
cGo6AA0DmnjPvuFHRpW2paYD2LiY+/ZlARv27X2l6QBx1wP792pxlp/YtB2C
wBoe2O970X5drkXHYQnYggf2dmcsrIsS9Ry+aYBMeGCftebUkoogAwePh2AP
2L/f+DG1dK2hw6yZIPDQPqT9craFt7HDG5B3Xj+0N6+qX5BoaQr1/yP7tztF
z7zuMncAO6f/kf32rVe2WURZOUCMe2TfUC1XEXTG1sEYDB7bG8xbrifC7ejQ
Cg6fx/Z8x9YxzD7k7AAyjev6Y3smcf/1mu7uDppgDz6xb2vIWiH1xduhNCw4
Vcz5CTz8AapbtLA=
      "]], 
     LineBox[{{0.8411725519888572, 60.}, {0.85, 58.86948246356413}, {0.86, 
      59.34626183294534}, {0.8629617850360661, 60.}}], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQ3ZofFzrzwkd7BjDwc3gTuEOu9fVH+wTePlleb28H
0XXuD6tEPtmrBbcbBEp6ONhxXV9cYPvJvqJ7xp24ya4O6Wkg8Ml+363cv069
zg4TDn3ViOn/ZP/5zYvZwS8cHXYCTQvc8cn+vVRx0dI+B4dHVSJAEz/Zr5h5
bUHBAzsHbpBxXJ/t51w62OfLZOtgYgwCn+33zb+X9qLA2iG2H2TgZ/tJPyS3
1MhZObS9Bjnws71G3bmlcQyWDutBzlv32X6hps4DYz4Lhxsg465/tnc7HLAr
1dHcgRHsry/259ripHdPMXPQjAEZCORrmDvysZg5BIG8G/jF/vnsZ4vFekwd
qkHOq/piv2+24G5HLVOHJSDjFn+xX59tojX9jonD2TMg8MW+beo7sWULTRy+
aYAM/GLP+/tNfFWFiYM8yLtyX+0dL1ZZzUwwcfAAOc/9q/3rXxJdrFEmDoUg
4wq+2t9SYzT1TTVxmDUTBL7aa2uf/7Ww2cTh8Fewgfa2gkeMmbabQOPjq/2v
S/yPKphMofHxzf7VnLRJjVmm0Pj4Zv90rWX50q+m0Pj4Zm/R6t5dvtYMGh/f
7HU/bzxmssAcGh/f7C/lFYX1PLaAxsc3+2R97XUzZlpB4+O7/XbdKSz2v2yg
8fHdvvxNhyiLsQM0Pr7bi93ybJ953AkaH9/tjQ+VPCl65+YQflO3asua7/D0
BAAzsRk5
      "]], LineBox[CompressedData["
1:eJw11QlMk2cYB/CvX1sUjwzj7QyGgcOJSDawpYXy/jlKOYoK82TFRRTKlCFe
EA4lDJB4Ak4QECdRQcGJTiYeOM855hRlKgJOVC5BWfACDRTK+LqHN2maps2/
z/v8/k2tQtcFhfEcxyUOPYTnmnnN8+On9DLOdOZjRlpn4HnLXvZ7/ltNg4MW
Pk3xE8o0vay4eNeZ4+O8sV41qu5IdC/LrdSN2Z/ugfw84fQy5yu+HVYLgRs9
s3QZ13tZC7/TKe60Cv8OpaV19rKJ01jpvRIXTCzTDCX2sRUDNQc8FEq4CXGq
PtYXLQqpt1dAHy6cPnYg/v5O2++ckXldCOxjgX8dqdpSJ8cFS2HAPlaSPn7s
0bVyNAvjNfWxd42J+2OnyzFaiBtlYA9vLvDf0iKDk6NwDGym86R40SUZQjKE
QANT3xuVsP2wDNuE66YZWPel8SUx+2Q4JYxXZmCl5mMt/8yQoV6IqzOwrKA3
E97slUFk2lM/uyHTz64okGG2TgjsZzGNJxSf/SxDkHDdwH7mZqOZ+v1VGRKE
8eL72RoXi8ieehmOCnFH+tkMa/Ov5T0yVN8RTj976tk2948JcnwQ1tfTz4o6
M59r5HLyGGC1GTLr9To5eQywD9h9jk+Vk8cAU4VGzak6KSePAfbDqjuWWQ1y
8hhgnZhRqxjhTB5Dn29NsiqUOZOHkVmkPoo/pncmDyPbPlfjLs93Jg8jS4z4
20Z5d9jDyI4utTt2UKwgDyPT2UeXByoV5GFkk2v1Gp8NCvIYZMk7J9htPqEg
j0EWidby6jYFeQyyjpuRWT5WSvIYZJPzJIcbQ5TkMfT+5cbqtANK8hhkFtY7
2pWPlfi/txw22UuzPk4d7hcHbWe6zblgF3xh8uHwT9qews0FLjCtS8XBsSAz
x+GZC3lxKL8rnt78mStM1w3ncDQ88Lcdelfy43A3NmaD7UlXmMbN4BC8b1x2
xXtX8uSQ0F5aJ3NRwRR3nkPktwbVsRQV+XK4nZA0aUS1ivbD4fHKlveLJ7uR
N4dTy1cd/zHUjfYlQnjuQ1wtcyN/ET4syeGeGNxgWp+jCFbJL0PafRn1QYTq
x6eNzbkMpuvqRFCqd5+918GoHyK8rixiddMBU1yaCFu7tbiqBvVFhJFRg8nW
6wDT+sqGvr9KfEmUN/x7FiHOqbbimxuAabw6EQ5FrPX/qgvUJxGyDDmh26a6
kwePNOfo7mVqd/LgcTP90YgT693Jg0dKg/GXLT+5U994KEo+mXT/tjt58NgV
fGt1Sa879Y9HXK3iiWSWB3nwSNXHV7Ut8aA+8lg0JnZrwDYP8uAxb9nlMFWF
B/WTx8PFy7sqXniQBw/zytLsysme5MHj+ctFbVpfT/LgccHj842RCZ7kIcbc
5aObPi3zJA8xEkvMGnVNntRnMQ7G2lt9OdGLPMR4sr1kY76vF3kMvY67Upy/
1Ys8xLi4oiHX8Vcv8hDDOi/bSf/KizzEmLK3IVpupSYPMcLQsbB4mZo8xIhZ
mNh6NlNNHmJsutOmibilJg8xnIKTC6/w3uQhgfagvcNlV2/ykMCvoMYuPNab
PCSouW/z6sIZb/KQ4F1SdlVllzd5SBC0Y6pDlJ2GPCRQu+rzHkRoyEOCFSPt
dncVa8hDghTmfuham4Y8JHCseLdhwUwf8pAgbKnTxfwwH/KQQFf0cl5xsQ95
SNBtN7tiU4cPeUjw4MX2aeZ2vuQhBY6sDgqP8iUPKV6FzgnJOONLHlJU3bro
l/7RlzykWFtY5BKo8iMPKabE5qx8k+JHHlKkbi4a1N/2Iw8pysPPrakc708e
UsyxeGbepfMnDyl6Wq8tER/zJw8pLttyT41v/clDiro9haxVpSUPKVYmJTmc
26ElDzMM9lzbnFCvJQ8znHDSvnayDSAPM/jPd93THhNAHmZ4WhoRvL8qAI5s
Ucs+fzMM/1//B0FEWtM=
      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"Precession Rate (\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SuperscriptBox[\\\"\[Null]\\\", \\\"\[Prime]\[Prime]\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"''\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)/y)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}, {60, 
       FormBox["60", TraditionalForm]}, {80, 
       FormBox["80", TraditionalForm]}}, None}, {{{0, 
       FormBox["0", TraditionalForm]}, {1, 
       FormBox["1", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 4.}, {0., 60.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8113963138407717`*^9, 3.869289650980397*^9, 
  3.86928969828916*^9, 3.869290091869936*^9, 3.869295440797608*^9, 
  3.869305102887146*^9, 3.86930518895053*^9, 3.86930532909167*^9, 
  3.869305407833185*^9, 3.890977071120327*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"3366f7a3-da4b-4942-bda7-0aaa6ab1a3c6"]
}, Open  ]],

Cell["\<\
Create a graphics object of lines denoting the secular eigenfrequencies.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ba5135e1-2c59-491a-aa78-65a25046a98e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gin", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "#"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4", ",", "#"}], "}"}]}], "}"}], "]"}], "&"}], ",", " ", 
      "gg"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fin", " ", "=", " ", 
   RowBox[{"Graphics", "[", "\n", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Dashing", "[", 
        RowBox[{"{", 
         RowBox[{"0.01", ",", " ", "0.01"}], "}"}], "]"}], "}"}], ",", "\n", 
      "     ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "#"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"4", ",", "#"}], "}"}]}], "}"}], "]"}], "&"}], ",", " ", 
        
        RowBox[{"-", "ff"}]}], "]"}]}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.86929010621137*^9, 3.8692901062189627`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"503000d8-08fc-4e54-a893-1eb454f569cf"],

Cell["Display the plot with the eigenfrequencies.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c8e91a1b-2259-40cb-816b-efcaf106f07e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"pin", ",", "gin", ",", "fin", ",", "linesin"}], "]"}]], "Input",
 CellChangeTimes->{{3.8692960787809477`*^9, 3.86929607878654*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"c4b21143-d0dd-4903-8a8a-e01274524869"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQPWsmCOy07zFTVCx+/9heM6b/0FeNPfZrJty9KKr3
3H6nXOvrwB377H9d3t7Av/SV/ZICW67riw/Y+/Ws2sEe/s7+TeAOoIqD9h4d
Qt0HlT/amxiDwGF76UVKGxttP9tXi6xzf1h1xP7H9TtCs6u/2h/+qgG04ag9
Z/XdW7MefrcHGgY08bj9vweLqj8W/7IPAhkXeMJ+cqnKUgOLv/YQ9520/8GW
vmuDFIPDoyqQgafsPz6wfmm3i9EB4t4z9qdNrFj6G5gdCkHOKzhrvyiN455V
KasDxP3n7C+FN3imLWJ3YACDC/YLHPcW3RPlcoD454L91O0bdt55xOPg8RBk
wUX7L6UtbQVCAg4Q/1201zgiv92OSchhwiGQBy7Z850tP3o/XsQB4t/L9h9X
it6+HSPuAPbO9cv2yXWlOeU+0g4Q/1+x/3f/tcznRAUHeZBz5K7ay3MvW9BT
pOIANu7QVXvzZDvdpYLaDmlgcM3e7843t2krjR0g4XPdvrfz6O2sXQ4OzRd1
OC/nXLeH+MPPAQC/QtIu
       "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQfTBxdUO/yi17BjDwc7Djur64wPaW/eqKw8c50twd
HlWJrHN/eMs+w60rkdXPyqHtdeAOudbb9j3vcw80rjFy0IrpP/RV4479P/Hw
fqVCPYdzZ0Dgjr1Gw7rv28W0HQpsQQbetb//fbPbsU5NB5BpVSL37Ld1M0RG
cGo6AA0DmnjPvuFHRpW2paYD2LiY+/ZlARv27X2l6QBx1wP792pxlp/YtB2C
wBoe2O970X5drkXHYQnYggf2dmcsrIsS9Ry+aYBMeGCftebUkoogAwePh2AP
2L/f+DG1dK2hw6yZIPDQPqT9craFt7HDG5B3Xj+0N6+qX5BoaQr1/yP7tztF
z7zuMncAO6f/kf32rVe2WURZOUCMe2TfUC1XEXTG1sEYDB7bG8xbrifC7ejQ
Cg6fx/Z8x9YxzD7k7AAyjev6Y3smcf/1mu7uDppgDz6xb2vIWiH1xduhNCw4
Vcz5CTz8AapbtLA=
       "]], 
      LineBox[{{0.8411725519888572, 60.}, {0.85, 58.86948246356413}, {0.86, 
       59.34626183294534}, {0.8629617850360661, 60.}}], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQ3ZofFzrzwkd7BjDwc3gTuEOu9fVH+wTePlleb28H
0XXuD6tEPtmrBbcbBEp6ONhxXV9cYPvJvqJ7xp24ya4O6Wkg8Ml+363cv069
zg4TDn3ViOn/ZP/5zYvZwS8cHXYCTQvc8cn+vVRx0dI+B4dHVSJAEz/Zr5h5
bUHBAzsHbpBxXJ/t51w62OfLZOtgYgwCn+33zb+X9qLA2iG2H2TgZ/tJPyS3
1MhZObS9Bjnws71G3bmlcQyWDutBzlv32X6hps4DYz4Lhxsg465/tnc7HLAr
1dHcgRHsry/259ripHdPMXPQjAEZCORrmDvysZg5BIG8G/jF/vnsZ4vFekwd
qkHOq/piv2+24G5HLVOHJSDjFn+xX59tojX9jonD2TMg8MW+beo7sWULTRy+
aYAM/GLP+/tNfFWFiYM8yLtyX+0dL1ZZzUwwcfAAOc/9q/3rXxJdrFEmDoUg
4wq+2t9SYzT1TTVxmDUTBL7aa2uf/7Ww2cTh8Fewgfa2gkeMmbabQOPjq/2v
S/yPKphMofHxzf7VnLRJjVmm0Pj4Zv90rWX50q+m0Pj4Zm/R6t5dvtYMGh/f
7HU/bzxmssAcGh/f7C/lFYX1PLaAxsc3+2R97XUzZlpB4+O7/XbdKSz2v2yg
8fHdvvxNhyiLsQM0Pr7bi93ybJ953AkaH9/tjQ+VPCl65+YQflO3asua7/D0
BAAzsRk5
       "]], LineBox[CompressedData["
1:eJw11QlMk2cYB/CvX1sUjwzj7QyGgcOJSDawpYXy/jlKOYoK82TFRRTKlCFe
EA4lDJB4Ak4QECdRQcGJTiYeOM855hRlKgJOVC5BWfACDRTK+LqHN2maps2/
z/v8/k2tQtcFhfEcxyUOPYTnmnnN8+On9DLOdOZjRlpn4HnLXvZ7/ltNg4MW
Pk3xE8o0vay4eNeZ4+O8sV41qu5IdC/LrdSN2Z/ugfw84fQy5yu+HVYLgRs9
s3QZ13tZC7/TKe60Cv8OpaV19rKJ01jpvRIXTCzTDCX2sRUDNQc8FEq4CXGq
PtYXLQqpt1dAHy6cPnYg/v5O2++ckXldCOxjgX8dqdpSJ8cFS2HAPlaSPn7s
0bVyNAvjNfWxd42J+2OnyzFaiBtlYA9vLvDf0iKDk6NwDGym86R40SUZQjKE
QANT3xuVsP2wDNuE66YZWPel8SUx+2Q4JYxXZmCl5mMt/8yQoV6IqzOwrKA3
E97slUFk2lM/uyHTz64okGG2TgjsZzGNJxSf/SxDkHDdwH7mZqOZ+v1VGRKE
8eL72RoXi8ieehmOCnFH+tkMa/Ov5T0yVN8RTj976tk2948JcnwQ1tfTz4o6
M59r5HLyGGC1GTLr9To5eQywD9h9jk+Vk8cAU4VGzak6KSePAfbDqjuWWQ1y
8hhgnZhRqxjhTB5Dn29NsiqUOZOHkVmkPoo/pncmDyPbPlfjLs93Jg8jS4z4
20Z5d9jDyI4utTt2UKwgDyPT2UeXByoV5GFkk2v1Gp8NCvIYZMk7J9htPqEg
j0EWidby6jYFeQyyjpuRWT5WSvIYZJPzJIcbQ5TkMfT+5cbqtANK8hhkFtY7
2pWPlfi/txw22UuzPk4d7hcHbWe6zblgF3xh8uHwT9qews0FLjCtS8XBsSAz
x+GZC3lxKL8rnt78mStM1w3ncDQ88Lcdelfy43A3NmaD7UlXmMbN4BC8b1x2
xXtX8uSQ0F5aJ3NRwRR3nkPktwbVsRQV+XK4nZA0aUS1ivbD4fHKlveLJ7uR
N4dTy1cd/zHUjfYlQnjuQ1wtcyN/ET4syeGeGNxgWp+jCFbJL0PafRn1QYTq
x6eNzbkMpuvqRFCqd5+918GoHyK8rixiddMBU1yaCFu7tbiqBvVFhJFRg8nW
6wDT+sqGvr9KfEmUN/x7FiHOqbbimxuAabw6EQ5FrPX/qgvUJxGyDDmh26a6
kwePNOfo7mVqd/LgcTP90YgT693Jg0dKg/GXLT+5U994KEo+mXT/tjt58NgV
fGt1Sa879Y9HXK3iiWSWB3nwSNXHV7Ut8aA+8lg0JnZrwDYP8uAxb9nlMFWF
B/WTx8PFy7sqXniQBw/zytLsysme5MHj+ctFbVpfT/LgccHj842RCZ7kIcbc
5aObPi3zJA8xEkvMGnVNntRnMQ7G2lt9OdGLPMR4sr1kY76vF3kMvY67Upy/
1Ys8xLi4oiHX8Vcv8hDDOi/bSf/KizzEmLK3IVpupSYPMcLQsbB4mZo8xIhZ
mNh6NlNNHmJsutOmibilJg8xnIKTC6/w3uQhgfagvcNlV2/ykMCvoMYuPNab
PCSouW/z6sIZb/KQ4F1SdlVllzd5SBC0Y6pDlJ2GPCRQu+rzHkRoyEOCFSPt
dncVa8hDghTmfuham4Y8JHCseLdhwUwf8pAgbKnTxfwwH/KQQFf0cl5xsQ95
SNBtN7tiU4cPeUjw4MX2aeZ2vuQhBY6sDgqP8iUPKV6FzgnJOONLHlJU3bro
l/7RlzykWFtY5BKo8iMPKabE5qx8k+JHHlKkbi4a1N/2Iw8pysPPrakc708e
UsyxeGbepfMnDyl6Wq8tER/zJw8pLttyT41v/clDiro9haxVpSUPKVYmJTmc
26ElDzMM9lzbnFCvJQ8znHDSvnayDSAPM/jPd93THhNAHmZ4WhoRvL8qAI5s
Ucs+fzMM/1//B0FEWtM=
       "]]}}, {{}, {}}}, {LineBox[{{0, 5.46326}, {4, 5.46326}}], 
    LineBox[{{0, 7.34474}, {4, 7.34474}}], 
    LineBox[{{0, 17.32832}, {4, 17.32832}}], 
    LineBox[{{0, 18.00233}, {4, 18.00233}}], 
    LineBox[{{0, 4.29591}, {4, 4.29591}}], 
    LineBox[{{0, 27.77406}, {4, 27.77406}}], 
    LineBox[{{0, 2.71931}, {4, 2.71931}}], 
    LineBox[{{0, 0.63332}, {4, 0.63332}}], 
    LineBox[{{0, -19.18225}, {4, -19.18225}}], 
    LineBox[{{0, 51.25222}, {4, 51.25222}}]}, 
   {Dashing[{0.01, 0.01}], LineBox[{{0, 5.21054}, {4, 5.21054}}], 
    LineBox[{{0, 6.5708}, {4, 6.5708}}], 
    LineBox[{{0, 18.74359}, {4, 18.74359}}], 
    LineBox[{{0, 17.63331}, {4, 17.63331}}], LineBox[{{0, 0.}, {4, 0.}}], 
    LineBox[{{0, 25.73355}, {4, 25.73355}}], 
    LineBox[{{0, 2.90266}, {4, 2.90266}}], 
    LineBox[{{0, 0.67752}, {4, 0.67752}}]}, 
   {Thickness[0.004], 
    StyleBox[{{LineBox[{{0.3871, 60}, {0.3871, 58}}], 
       LineBox[{{0.72333, 60}, {0.72333, 58}}], 
       LineBox[{{1.00002, 60}, {1.00002, 58}}], 
       LineBox[{{1.52364, 60}, {1.52364, 58}}]}, {
       InsetBox["\<\"M\"\>", {0.3871, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"V\"\>", {0.72333, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"E\"\>", {1.00002, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"M\"\>", {1.52364, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]]}},
     FontFamily->"Times",
     FontSize->12]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"Precession Rate (\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SuperscriptBox[\\\"\[Null]\\\", \\\"\[Prime]\[Prime]\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"''\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)/y)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}, {60, 
       FormBox["60", TraditionalForm]}, {80, 
       FormBox["80", TraditionalForm]}}, None}, {{{0, 
       FormBox["0", TraditionalForm]}, {1, 
       FormBox["1", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 4.}, {0., 60.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.869305102976988*^9, 3.869305189044376*^9, 
  3.869305329124934*^9, 3.8693054078719788`*^9, 3.890977071159216*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"5b545147-49d5-44f5-8169-0845254e1c64"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQPWsmCOy07zFTVCx+/9heM6b/0FeNPfZrJty9KKr3
3H6nXOvrwB377H9d3t7Av/SV/ZICW67riw/Y+/Ws2sEe/s7+TeAOoIqD9h4d
Qt0HlT/amxiDwGF76UVKGxttP9tXi6xzf1h1xP7H9TtCs6u/2h/+qgG04ag9
Z/XdW7MefrcHGgY08bj9vweLqj8W/7IPAhkXeMJ+cqnKUgOLv/YQ9520/8GW
vmuDFIPDoyqQgafsPz6wfmm3i9EB4t4z9qdNrFj6G5gdCkHOKzhrvyiN455V
KasDxP3n7C+FN3imLWJ3YACDC/YLHPcW3RPlcoD454L95O0bdt55xOPg8RBk
wUX7L6UtbQVCAg4Q/1201zgiv92OSchhwiGQBy7Z850tP3o/XsQB4t/L9h9X
it6+HSPuAPbO9cv2yXWlOeU+0g4Q/1+x/3f/tcznRAUHeZBz5K7ay3MvW9BT
pOIANu7QVXvzZDvdpYLaDmlgcM3e7843t2krjR0g4XPdvqfz6O2sXQ4OzRd1
OC/nXLeH+MPPAQC9utIr
       "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQfTBxdUO/yi17BjDwc7Djur64wPaW/eqKw8c50twd
HlWJrHN/eMs+w60rkdXPyqHtdeAOudbb9j3vcw80rjFy0IrpP/RV4479b/Hw
fqVCPYdzZ0Dgjr1qw7rv28W0HQpsQQbetb//fbPbsU5NB5BpVSL37Ld1M0RG
cGo6AA0DmnjPvuFHRpW2paYD2LiY+/ZlARv27X2l6QBx1wP792pxlp/YtB2C
wBoe2O970X5drkXHYQnYggf2dmcsrIsS9Ry+aYBMeGCftebUkoogAwePh2AP
2L/b+DG1dK2hw6yZIPDQPrj9craFt7HDG5B3Xj+0N6uqX5BoaQr1/yP7tztF
z7zuMncAO6f/kf22rVe2WURZOUCMe2TfUC1XEXTG1sEYDB7bG8xbrifC7ejQ
Cg6fx/a8x9YxzD7k7AAyjev6Y3smcf/1mu7uDppgDz6xb2vIWiH1xduhNCw4
Vcz5CTz8AaBztKU=
       "]], 
      LineBox[{{0.8411725519888572, 60.}, {0.85, 58.869482463564125`}, {0.86, 
       59.34626183294532}, {0.8629617850360661, 60.}}], 
      LineBox[CompressedData["
1:eJw9kl9IU2EYxudYN8YMwUkWLboZ0zUKdo6bq/m+M3KGGE2pIGxFsQVFuVYw
OUUQsRlpM8zI04Qca9FFTgIjSxikUTdptYusIWH2b7FheP4tFkH7xkcPfHx3
P56H37vlWE+nV61SqQylR/5Qj2c//3YVVOXsxbx7Sh/KrYJHG9mkbW9HXdL1
masRwNDVt91d14bNlQtxv0OAYP/IoufmbjzhIxEglTn9t+X6LrwxIxu7BwUQ
89loV9aJT0s095QAvzacCyQiiMtcTYkowAP+/Zh/qRnXElylCKPp55EOtQMZ
C4kIqbuffFn/Djw8SIAiDP2um7yot2M4RwqKYLw0n/ComnCC1EuKEKvfumSp
suEHglsQoXV23zOv04oV5V0SzIc9G6eHG7G+mwAlmDNanVWaRuwkc90S/Ih+
j9cOsHiB1OMkSEWrp50NLN4juLgEE6eYhtuLDM69JpEgfGul9n6MQcVIgBJo
/+SPcL0MbiZz9TI433F2/iiDbaSeS4Zccf21NYcYPEtwfhkyhgq2w8vgHZ5E
BpPpTTF2hcFZuQwER/ULi/oJQ33IUEyvW+5Vs9SHAj9HfUOXT7LUhwLfxpuC
CZmlPhSwhVz9wfFG6kMBs/joJTNmpT4USJ8JHBj4YqM+FDi+zZQc4e3URwEe
m4c1UNxJfRQgmL+q01iQ+iiALrOnj3/VQn0UwDJz/mtgpRUPfjRzkw8L/+/p
HyoxGTE=
       "]], LineBox[CompressedData["
1:eJw11QlMk2cYB/CvX1sUjwwjgjiDQXA4EMlG7QXlfVoopbSoME9WXEShTBni
AUxACSIQ8ACcICBOIpfFidcEFeY5x5yiTEXAicolKAuigqYUyvp1D2/SkKbl
3+d9fv+mDmFbgsNpiqKSTA/mb9OSzqUJs/WEMp+lMC+tP+iSvZ78XvRO0eau
Bv+OBOtqhZ5UVOw/f3KGH2yVTGkpjdGTgjrNtCMZMigqZI6eCK8p+xyWA9wa
XqjJvqknXfQ+3s6zEvjXlJbWryez5pCqBzpPmFWtMCWOkNCxpqMykRi8mTjJ
CBmJYYW2uolAG8GcEXI04eE+5++FkHOTCRwhQX+VNuxqEcBle2bAEaLLmDm9
bLMAOpnxOkbIYHvSkfi5ApjKxE0xkMe3l6l2dfGB58EcA1kgtElg1fMhNJsJ
NBD5gymJmSf4kM5cN81Ahupn6uIO8+EMM161gVRZTrf/M5sPrUxci4HkBA9a
Dx7iA8u8p1Fyi691qSnmg4uGCRwlce2nRPN/4UMwc92gUeLtpLD74TofEpnx
EkbJJk+rqOFWPpQxcaWjZJ6j5TeCYT403mPOKHnu07P4D2sBfGTWNzxKyvtz
XioEAvQYI83ZfMetGgF6jJGPcKCW3itAjzEiCYte1HBagB5jZM+Ge/a5bQL0
GCP9MK9ZNEmIHqb3dyc7lPCF6GEkVnufJFRqhehhJJmLFVJBkRA9jCQp8m8n
8f0JDyMpW+1aeYwtQg8j0bjFXAgSi9DDSGybtQr/bSL0GCcp+6xdY0+J0GOc
REH3hcYeEXqMk77bUbn+DmL0GCe2hZwT7aFi9DC9frW9Me2oGD3GiZVjVq/4
qRj+7y0FO9y4uZ/sJvpFgbo/w6k2xBO+NPtQ8E/awZLYYk8wr0tCgUdxTr77
C0/0ouDCffbczvleYL5uBAVlEUG/ZWm90I+C+/Fx25xPe4F53GwKQg7PyKv5
4IWeFCT2VrXwPSVgjrtEQdR3BkllqgR9KbibmGwzqVGC+6Hg6fquDyttvdGb
gjNrN5z8Kcwb98WCiILHcL3aG/1Z8HFVPvXM4A3m9XmwwCHldWivkmAfWND4
9Kyxs4CA+boaFojlBy4+6CPYDxa8rSsnLXMBzHFpLNg9pIbrcsC+sGBy9HiK
4xYA8/qqTZ/fwK5nFU58n1nwI6+55ttbAObxWlhwPHKz6usBwD6xINeQH5Zu
J0UPGtKEMUNr5FL0oOF2xpNJp7ZK0YOG1DbjuV0/S7FvNIh0n9k8vCtFDxr2
h9zZqNNLsX807GwWPeMslKEHDXu1CQ09q2TYRxpWTIvfHZguQw8alqy5Gi6p
kWE/aXi8cu1AzSsZetBgWVeVV2frgx40vHy9oket9EEPGi7LvtgeleiDHmxY
vHZqx+fVPujBhiSdRbumwwf7zIZj8W4OX83yRQ82PMvUbS9S+qKH6fnOaxVF
u33Rgw1X1rUVePzqix5scCzM42nf+KIHG2YfaosROMjRgw3h0Le8Yo0cPdgQ
tzyp+2KOHD3YsONejyLyjhw92MALSSm5RvuhBwfUx9zcr3r5oQcHFMVNrhHx
fujBgaaHTm8un/dDDw68T85rqBvwQw8OBGfZuUe7KtCDA3IvbeGjSAV6cEAz
2fXAQIUCPTiQSqTHb/Qo0IMDHjXvty1b4I8eHAhfzbtSFO6PHqb/L3+9pKLC
Hz04MOTqUrOjzx89OPDoVeYcS1clenABSjcGR0Qr0YMLb8IWhWafV6IHFxru
XAnI+KREDy5sLin3DJIEoAcXbOLz1w+mBqAHF/bElo9r7wagBxfORdRuqpup
Qg8uuFi9sBzQqNCDC0PdN1axK1XowYV6Z+q58Z0KPbjQfLCEdEvU6MGFdcnJ
7rVZavSwAOPwjdjEVjV6WICOp37Lcw5EDwtQLfU62BsXiB4W8LwqMuRIQyB4
kBVdh1UWMPF7/R8QDFq2
       "]]}}, {{}, {}}}, {LineBox[{{0, 5.46326}, {4, 5.46326}}], 
    LineBox[{{0, 7.34474}, {4, 7.34474}}], 
    LineBox[{{0, 17.32832}, {4, 17.32832}}], 
    LineBox[{{0, 18.00233}, {4, 18.00233}}], 
    LineBox[{{0, 4.29591}, {4, 4.29591}}], 
    LineBox[{{0, 27.77406}, {4, 27.77406}}], 
    LineBox[{{0, 2.71931}, {4, 2.71931}}], 
    LineBox[{{0, 0.63332}, {4, 0.63332}}], 
    LineBox[{{0, -19.18225}, {4, -19.18225}}], 
    LineBox[{{0, 51.25222}, {4, 51.25222}}]}, 
   {Dashing[{0.01, 0.01}], LineBox[{{0, 5.21054}, {4, 5.21054}}], 
    LineBox[{{0, 6.5708}, {4, 6.5708}}], 
    LineBox[{{0, 18.74359}, {4, 18.74359}}], 
    LineBox[{{0, 17.63331}, {4, 17.63331}}], LineBox[{{0, 0.}, {4, 0.}}], 
    LineBox[{{0, 25.73355}, {4, 25.73355}}], 
    LineBox[{{0, 2.90266}, {4, 2.90266}}], 
    LineBox[{{0, 0.67752}, {4, 0.67752}}]}, 
   {Thickness[0.004], 
    StyleBox[{{LineBox[{{0.3871, 60}, {0.3871, 58}}], 
       LineBox[{{0.72333, 60}, {0.72333, 58}}], 
       LineBox[{{1.00002, 60}, {1.00002, 58}}], 
       LineBox[{{1.52364, 60}, {1.52364, 58}}]}, {
       InsetBox["\<\"M\"\>", {0.3871, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"V\"\>", {0.72333, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"E\"\>", {1.00002, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"M\"\>", {1.52364, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]]}},
     FontFamily->"Times",
     FontSize->12]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"Precession Rate (\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SuperscriptBox[\\\"\[Null]\\\", \\\"\[Prime]\[Prime]\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"''\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)/y)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}, {60, 
       FormBox["60", TraditionalForm]}, {80, 
       FormBox["80", TraditionalForm]}}, None}, {{{0, 
       FormBox["0", TraditionalForm]}, {1, 
       FormBox["1", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{39.5, 4.5}, {40., 8.}},
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 4.}, {0., 60.}},
  PlotRangeClipping->True,
  PlotRangePadding->Automatic,
  Ticks->{Automatic, Automatic}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.8692992082237787`*^9, 
  3.869299320276781*^9},ExpressionUUID->"d8630a45-cac7-41e9-a98f-\
617ed399a1df"]
}, Open  ]],

Cell["\<\
Find the locations where the eigenfrequencies in the main asteroid belt match \
the precession rate.  First select the values of semi-major axis between 1.75 \
and 3 AU.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869301136744636*^9, 3.869301217261591*^9}, {
  3.869304922156495*^9, 3.8693049375922413`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f552633e-c63f-401a-afa2-a8f056d9249a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"subset", "=", 
   RowBox[{"Select", "[", 
    RowBox[{"precessinner", ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ">", "1.75"}], "&&", " ", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "3"}]}], ")"}], "&"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.869299897427059*^9, 3.869299899931335*^9}, {
   3.8693005019622927`*^9, 3.869300534122243*^9}, {3.869300566433213*^9, 
   3.8693006040371723`*^9}, {3.8693007569507113`*^9, 3.869300797434924*^9}, {
   3.869300927937532*^9, 3.869300928805764*^9}, {3.86930098528277*^9, 
   3.869300989811881*^9}, 3.869301086548996*^9},
 CellLabel->"In[21]:=",ExpressionUUID->"71d1e334-7049-4144-acde-527a1eeb4c2f"],

Cell["Reverse the coordinate pairs.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869301136744636*^9, 3.869301217261591*^9}, {
  3.8693043263622303`*^9, 3.8693043378965473`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"11b613ed-152d-43ad-b2c7-a3919834cafa"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tsubset", "=", 
   RowBox[{"Transpose", "[", "subset", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rsubset", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tsubset", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"tsubset", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.869303954568986*^9, 3.869304026178816*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"07e27dcc-5021-47b0-8e84-b1b02c1c7a9e"],

Cell["Create an Interpolating function.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869301136744636*^9, 3.8693012508163147`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"868f759c-230a-49b1-b3e7-c701b89eadd6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"intsubset", "=", 
   RowBox[{"Interpolation", "[", "rsubset", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.869301002070409*^9, 3.869301014591907*^9}, 
   3.8693010919034357`*^9, 3.869304032402649*^9},
 CellLabel->"In[24]:=",ExpressionUUID->"daf29881-2698-4069-a662-e4989c4e9250"],

Cell["Define the eigenfrequencies of interest.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869301136744636*^9, 3.8693012508163147`*^9}, {
  3.869304359842477*^9, 3.869304378442931*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"72b4a39d-91e3-4a97-8341-4b277a76cb16"],

Cell[BoxData[
 RowBox[{
  RowBox[{"intersects", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"ff", "[", 
       RowBox[{"[", "6", "]"}], "]"}]}], ",", 
     RowBox[{"gg", "[", 
      RowBox[{"[", "6", "]"}], "]"}], ",", 
     RowBox[{"gg", "[", 
      RowBox[{"[", "10", "]"}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.869301336662962*^9, 3.869301401160461*^9}, 
   3.8693043861695023`*^9},
 CellLabel->"In[25]:=",ExpressionUUID->"07a66928-5da8-40ce-8cc6-882dc01946ad"],

Cell["\<\
Use the interpolated function to estimate the location of the intersection \
points.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869301136744636*^9, 3.8693012508163147`*^9}, {
  3.869304359842477*^9, 3.869304433958439*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e5f464da-3f97-437e-9bdd-8df3e606eb4e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"intersections", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"intsubset", "[", "#", "]"}], "&"}], ",", "intersects"}], 
       "]"}], ",", "intersects"}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.869300936728986*^9, 3.869300941630568*^9}, {
  3.869301020982655*^9, 3.869301022663343*^9}, {3.869301420585948*^9, 
  3.869301438779471*^9}, {3.86930405892374*^9, 3.869304227090345*^9}, {
  3.869304264459298*^9, 3.8693042920430737`*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"cc9ead3e-0f3a-43ef-b5a4-676688f68977"],

Cell["Prepare the circles to be drawn on the plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869301136744636*^9, 3.8693012508163147`*^9}, {
  3.869304359842477*^9, 3.8693044583340607`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f6f8f764-8dbb-49b7-a151-4d281ab1317f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circs", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Circle", "[", 
         RowBox[{"#", ",", 
          RowBox[{"{", 
           RowBox[{"0.06", ",", "1.4"}], "}"}]}], "]"}], "&"}], ",", 
       "intersections"}], "]"}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.869299391157043*^9, 3.869299467281376*^9}, {
  3.86929952794461*^9, 3.869299532847816*^9}, {3.869299614432981*^9, 
  3.86929964072849*^9}, {3.869299762562533*^9, 3.8692998599559937`*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"2db8e010-878e-40c7-955b-c5d25deb53ef"],

Cell["Draw the final plot.  This is Fig.7.12a.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869301136744636*^9, 3.8693012508163147`*^9}, {
  3.869304359842477*^9, 3.869304477023861*^9}, {3.869305037462303*^9, 
  3.8693050493283777`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"16f02588-cf93-4678-82aa-ce490650ba17"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"pin", ",", "gin", ",", "fin", ",", "linesin", ",", "circs"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8692994850725718`*^9, 3.869299486556633*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"8adbb41c-def6-4f64-b1fe-c8b3d764c034"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQPWsmCOy07zFTVCx+/9heM6b/0FeNPfZrJty9KKr3
3H6nXOvrwB377H9d3t7Av/SV/ZICW67riw/Y+/Ws2sEe/s7+TeAOoIqD9h4d
Qt0HlT/amxiDwGF76UVKGxttP9tXi6xzf1h1xP7H9TtCs6u/2h/+qgG04ag9
Z/XdW7MefrcHGgY08bj9vweLqj8W/7IPAhkXeMJ+cqnKUgOLv/YQ9520/8GW
vmuDFIPDoyqQgafsPz6wfmm3i9EB4t4z9qdNrFj6G5gdCkHOKzhrvyiN455V
KasDxP3n7C+FN3imLWJ3YACDC/YLHPcW3RPlcoD454L91O0bdt55xOPg8RBk
wUX7L6UtbQVCAg4Q/1201zgiv92OSchhwiGQBy7Z850tP3o/XsQB4t/L9h9X
it6+HSPuAPbO9cv2yXWlOeU+0g4Q/1+x/3f/tcznRAUHeZBz5K7ay3MvW9BT
pOIANu7QVXvzZDvdpYLaDmlgcM3e7843t2krjR0g4XPdvrfz6O2sXQ4OzRd1
OC/nXLeH+MPPAQC/QtIu
       "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQfTBxdUO/yi17BjDwc7Djur64wPaW/eqKw8c50twd
HlWJrHN/eMs+w60rkdXPyqHtdeAOudbb9j3vcw80rjFy0IrpP/RV4479P/Hw
fqVCPYdzZ0Dgjr1Gw7rv28W0HQpsQQbetb//fbPbsU5NB5BpVSL37Ld1M0RG
cGo6AA0DmnjPvuFHRpW2paYD2LiY+/ZlARv27X2l6QBx1wP792pxlp/YtB2C
wBoe2O970X5drkXHYQnYggf2dmcsrIsS9Ry+aYBMeGCftebUkoogAwePh2AP
2L/f+DG1dK2hw6yZIPDQPqT9craFt7HDG5B3Xj+0N6+qX5BoaQr1/yP7tztF
z7zuMncAO6f/kf32rVe2WURZOUCMe2TfUC1XEXTG1sEYDB7bG8xbrifC7ejQ
Cg6fx/Z8x9YxzD7k7AAyjev6Y3smcf/1mu7uDppgDz6xb2vIWiH1xduhNCw4
Vcz5CTz8AapbtLA=
       "]], 
      LineBox[{{0.8411725519888572, 60.}, {0.85, 58.86948246356413}, {0.86, 
       59.34626183294534}, {0.8629617850360661, 60.}}], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQ3ZofFzrzwkd7BjDwc3gTuEOu9fVH+wTePlleb28H
0XXuD6tEPtmrBbcbBEp6ONhxXV9cYPvJvqJ7xp24ya4O6Wkg8Ml+363cv069
zg4TDn3ViOn/ZP/5zYvZwS8cHXYCTQvc8cn+vVRx0dI+B4dHVSJAEz/Zr5h5
bUHBAzsHbpBxXJ/t51w62OfLZOtgYgwCn+33zb+X9qLA2iG2H2TgZ/tJPyS3
1MhZObS9Bjnws71G3bmlcQyWDutBzlv32X6hps4DYz4Lhxsg465/tnc7HLAr
1dHcgRHsry/259ripHdPMXPQjAEZCORrmDvysZg5BIG8G/jF/vnsZ4vFekwd
qkHOq/piv2+24G5HLVOHJSDjFn+xX59tojX9jonD2TMg8MW+beo7sWULTRy+
aYAM/GLP+/tNfFWFiYM8yLtyX+0dL1ZZzUwwcfAAOc/9q/3rXxJdrFEmDoUg
4wq+2t9SYzT1TTVxmDUTBL7aa2uf/7Ww2cTh8Fewgfa2gkeMmbabQOPjq/2v
S/yPKphMofHxzf7VnLRJjVmm0Pj4Zv90rWX50q+m0Pj4Zm/R6t5dvtYMGh/f
7HU/bzxmssAcGh/f7C/lFYX1PLaAxsc3+2R97XUzZlpB4+O7/XbdKSz2v2yg
8fHdvvxNhyiLsQM0Pr7bi93ybJ953AkaH9/tjQ+VPCl65+YQflO3asua7/D0
BAAzsRk5
       "]], LineBox[CompressedData["
1:eJw11QlMk2cYB/CvX1sUjwzj7QyGgcOJSDawpYXy/jlKOYoK82TFRRTKlCFe
EA4lDJB4Ak4QECdRQcGJTiYeOM855hRlKgJOVC5BWfACDRTK+LqHN2maps2/
z/v8/k2tQtcFhfEcxyUOPYTnmnnN8+On9DLOdOZjRlpn4HnLXvZ7/ltNg4MW
Pk3xE8o0vay4eNeZ4+O8sV41qu5IdC/LrdSN2Z/ugfw84fQy5yu+HVYLgRs9
s3QZ13tZC7/TKe60Cv8OpaV19rKJ01jpvRIXTCzTDCX2sRUDNQc8FEq4CXGq
PtYXLQqpt1dAHy6cPnYg/v5O2++ckXldCOxjgX8dqdpSJ8cFS2HAPlaSPn7s
0bVyNAvjNfWxd42J+2OnyzFaiBtlYA9vLvDf0iKDk6NwDGym86R40SUZQjKE
QANT3xuVsP2wDNuE66YZWPel8SUx+2Q4JYxXZmCl5mMt/8yQoV6IqzOwrKA3
E97slUFk2lM/uyHTz64okGG2TgjsZzGNJxSf/SxDkHDdwH7mZqOZ+v1VGRKE
8eL72RoXi8ieehmOCnFH+tkMa/Ov5T0yVN8RTj976tk2948JcnwQ1tfTz4o6
M59r5HLyGGC1GTLr9To5eQywD9h9jk+Vk8cAU4VGzak6KSePAfbDqjuWWQ1y
8hhgnZhRqxjhTB5Dn29NsiqUOZOHkVmkPoo/pncmDyPbPlfjLs93Jg8jS4z4
20Z5d9jDyI4utTt2UKwgDyPT2UeXByoV5GFkk2v1Gp8NCvIYZMk7J9htPqEg
j0EWidby6jYFeQyyjpuRWT5WSvIYZJPzJIcbQ5TkMfT+5cbqtANK8hhkFtY7
2pWPlfi/txw22UuzPk4d7hcHbWe6zblgF3xh8uHwT9qews0FLjCtS8XBsSAz
x+GZC3lxKL8rnt78mStM1w3ncDQ88Lcdelfy43A3NmaD7UlXmMbN4BC8b1x2
xXtX8uSQ0F5aJ3NRwRR3nkPktwbVsRQV+XK4nZA0aUS1ivbD4fHKlveLJ7uR
N4dTy1cd/zHUjfYlQnjuQ1wtcyN/ET4syeGeGNxgWp+jCFbJL0PafRn1QYTq
x6eNzbkMpuvqRFCqd5+918GoHyK8rixiddMBU1yaCFu7tbiqBvVFhJFRg8nW
6wDT+sqGvr9KfEmUN/x7FiHOqbbimxuAabw6EQ5FrPX/qgvUJxGyDDmh26a6
kwePNOfo7mVqd/LgcTP90YgT693Jg0dKg/GXLT+5U994KEo+mXT/tjt58NgV
fGt1Sa879Y9HXK3iiWSWB3nwSNXHV7Ut8aA+8lg0JnZrwDYP8uAxb9nlMFWF
B/WTx8PFy7sqXniQBw/zytLsysme5MHj+ctFbVpfT/LgccHj842RCZ7kIcbc
5aObPi3zJA8xEkvMGnVNntRnMQ7G2lt9OdGLPMR4sr1kY76vF3kMvY67Upy/
1Ys8xLi4oiHX8Vcv8hDDOi/bSf/KizzEmLK3IVpupSYPMcLQsbB4mZo8xIhZ
mNh6NlNNHmJsutOmibilJg8xnIKTC6/w3uQhgfagvcNlV2/ykMCvoMYuPNab
PCSouW/z6sIZb/KQ4F1SdlVllzd5SBC0Y6pDlJ2GPCRQu+rzHkRoyEOCFSPt
dncVa8hDghTmfuham4Y8JHCseLdhwUwf8pAgbKnTxfwwH/KQQFf0cl5xsQ95
SNBtN7tiU4cPeUjw4MX2aeZ2vuQhBY6sDgqP8iUPKV6FzgnJOONLHlJU3bro
l/7RlzykWFtY5BKo8iMPKabE5qx8k+JHHlKkbi4a1N/2Iw8pysPPrakc708e
UsyxeGbepfMnDyl6Wq8tER/zJw8pLttyT41v/clDiro9haxVpSUPKVYmJTmc
26ElDzMM9lzbnFCvJQ8znHDSvnayDSAPM/jPd93THhNAHmZ4WhoRvL8qAI5s
Ucs+fzMM/1//B0FEWtM=
       "]]}}, {{}, {}}}, {LineBox[{{0, 5.46326}, {4, 5.46326}}], 
    LineBox[{{0, 7.34474}, {4, 7.34474}}], 
    LineBox[{{0, 17.32832}, {4, 17.32832}}], 
    LineBox[{{0, 18.00233}, {4, 18.00233}}], 
    LineBox[{{0, 4.29591}, {4, 4.29591}}], 
    LineBox[{{0, 27.77406}, {4, 27.77406}}], 
    LineBox[{{0, 2.71931}, {4, 2.71931}}], 
    LineBox[{{0, 0.63332}, {4, 0.63332}}], 
    LineBox[{{0, -19.18225}, {4, -19.18225}}], 
    LineBox[{{0, 51.25222}, {4, 51.25222}}]}, 
   {Dashing[{0.01, 0.01}], LineBox[{{0, 5.21054}, {4, 5.21054}}], 
    LineBox[{{0, 6.5708}, {4, 6.5708}}], 
    LineBox[{{0, 18.74359}, {4, 18.74359}}], 
    LineBox[{{0, 17.63331}, {4, 17.63331}}], LineBox[{{0, 0.}, {4, 0.}}], 
    LineBox[{{0, 25.73355}, {4, 25.73355}}], 
    LineBox[{{0, 2.90266}, {4, 2.90266}}], 
    LineBox[{{0, 0.67752}, {4, 0.67752}}]}, 
   {Thickness[0.004], 
    StyleBox[{{LineBox[{{0.3871, 60}, {0.3871, 58}}], 
       LineBox[{{0.72333, 60}, {0.72333, 58}}], 
       LineBox[{{1.00002, 60}, {1.00002, 58}}], 
       LineBox[{{1.52364, 60}, {1.52364, 58}}]}, {
       InsetBox["\<\"M\"\>", {0.3871, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"V\"\>", {0.72333, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"E\"\>", {1.00002, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"M\"\>", {1.52364, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]]}},
     FontFamily->"Times",
     FontSize->12]}, {CircleBox[{1.9428190992235326, 25.73355}, {0.06, 1.4}], 
    CircleBox[{2.0262665103633735, 27.77406}, {0.06, 1.4}], 
    CircleBox[{2.6373302256522573, 51.25222}, {0.06, 1.4}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"Precession Rate (\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SuperscriptBox[\\\"\[Null]\\\", \\\"\[Prime]\[Prime]\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"''\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)/y)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}, {60, 
       FormBox["60", TraditionalForm]}, {80, 
       FormBox["80", TraditionalForm]}}, None}, {{{0, 
       FormBox["0", TraditionalForm]}, {1, 
       FormBox["1", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}, {4, 
       FormBox["4", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 4.}, {0., 60.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8692994877392883`*^9, 3.869299643968272*^9, {3.869299766564033*^9, 
   3.869299862563987*^9}, 3.869304277042576*^9, 3.8693051031447153`*^9, 
   3.869305189217435*^9, 3.869305329191523*^9, 3.869305407941525*^9, 
   3.890977071228957*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"c29d2d6c-759d-4252-aa8c-57af304fc382"]
}, Open  ]],

Cell["\<\
Now consider the outer solar system.  Calculate the value of the free \
precession rate between 0.1 and 40 AU for epoch 1997.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869304966930976*^9, 3.869304986911107*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"42a8c10d-d498-4489-8574-9571b678f5d6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"precessouter", " ", "=", " ", "\n", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"BrouwerbigAA", "[", 
      RowBox[{"avalue", ",", " ", "1997"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"avalue", ",", " ", "0.1", ",", " ", "40", ",", " ", "0.1"}], 
      "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8692899207667313`*^9, 3.869289920771304*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"8d89b40e-6ccd-441e-82ca-a8e66af8c8eb"],

Cell["Plot the resulting values in the range 4 to 40 AU.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ea41f3db-d17e-4ca9-9c9d-4b458e80023d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pout", " ", "=", "\n", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"precessouter", ",", " ", 
    RowBox[{"Joined", "->", "True"}], ",", " ", "\n", 
    RowBox[{"Frame", "->", "True"}], ",", " ", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "40"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "60"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", "ylabel"}], "}"}]}], ",", 
    RowBox[{"RotateLabel", "->", "False"}], ",", 
    RowBox[{"AxesOrigin", "->", 
     RowBox[{"{", 
      RowBox[{"4", ",", "0"}], "}"}]}], ",", 
    RowBox[{"FrameTicks", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "20", ",", "40", ",", "60"}], "}"}], ",", 
         "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"10", ",", "20", ",", "30", ",", "40"}], "}"}], ",", 
         "None"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
    RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]}]], "Input",
 CellLabel->"In[30]:=",ExpressionUUID->"a0f1333b-c163-46d2-bf68-83a345a20e98"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0.1, 0.6229797026696402}, {0.2, 2.013032394665853}, {
      0.30000000000000004`, 5.840682433316474}, {0.34234439325543925`, 60.}}],
      LineBox[{{0.4613351220744746, 60.}, {0.5, 13.513566773169684`}, {0.6, 
      34.086553413242996`}, {0.6033928852519468, 60.}}], 
     LineBox[{{1.1295847011622868`, 60.}, {1.2000000000000002`, 
      27.441046170569955`}, {1.3000000000000003`, 20.631440575836212`}, {
      1.4000000000000001`, 22.6776053475962}, {1.4263249256150738`, 60.}}], 
     LineBox[{{1.5792350035261062`, 60.}, {1.6, 32.6260347709744}, {
      1.7000000000000002`, 22.734397535729062`}, {1.8000000000000003`, 
      23.08114903542798}, {1.9000000000000001`, 24.80557470428947}, {2., 
      27.101433814777423`}, {2.1, 29.800889402507703`}, {2.2, 
      32.8682711121765}, {2.3000000000000003`, 36.3126483232872}, {
      2.4000000000000004`, 40.16556181640701}, {2.5000000000000004`, 
      44.47455396392125}, {2.6, 49.30194734486096}, {2.7, 
      54.72601436034924}, {2.786208546492953, 60.}}], LineBox[CompressedData["

1:eJw91HlIFGEYx/HdLFOswINy2Q7dXZ09ZmZnZtW0yH5meXSILKVlm5WwRaek
GQqpHVJphJpUJmlrWdmhUS1p0aFFSodakgYVBlq5ZUiH9Edh5tqzPTC8/8x8
5vu+AxOYlm62jpPJZHGjl3N90fC+vfNFMGRjk0ArA/eusulHdiyBaWwYWCMd
N0vk8di4wTkMbB62mN73Mag46RwG3et4e9DkRWh75hwGA+ffscPbo8nTwiOl
qjlRvoA8LU7bj3a33gF5WsRZlMzTsPnkaaH8UFK+W5hHnhaHfAcHc1PnkqfD
OP+oJrfbEeTpkLGtLj5lXjh5OtQOm2dd6wsjT4dPp6t+f6sNJU+Hhos1U2yF
IeTp8dCy7M3dfSby9BgJ9OAaSyXy9Niyqt1rhV0kTw9ZwdJX5xwCeXqI0972
/WYF8gyoqj0r3RvhyTNgZ8D9tZOaOPIMaFYcy7GVs+QZgFs7z+QdNJBnQH3J
iqH+Ij15LN5W/hoyV+vIY9FZ/HW+9bGWPBZJjjUhg3IteSz8WrPzeuMZ8lj0
sxstK22u78zBT9FSUDA+mDwObpbNFQ1ZQeRxUARvmmH5oSGPQ/f6hLah3Rry
OGRkPclU+mjI46HzDvfZc11NHg+Uxqc71qjJ4xH9eeoEwU9NHo/IB8/McV0q
8njURxeVR1SryDPizpnbEzXZKvKMOG6x7YpKUZFnxM+ygMv9sSryjOBD8pMP
R7k8Iy7JA788jHV5AjK8pK2Jq+l+hQDfq8q9M3JVCBnzBZxImaNcVk/PLxWQ
7/HdHV9d7xNQcSXvT/VCNeRObo+A8dkBg9l1rv2MevrC1HBO88+7IUDdNC3x
dYvrvAR0SjuWjOTS+X4U8Cp2SOGfHPzPk4kwVDwvO5XMUJ+IRz0d65cf0FKf
CPOGP/bGAR31iUhL6zflHDVQn4hK9+LVpkMc9YmY3RG6NbPHSH0invuFLfZO
EqlPHO1/mtk20UR9Ioo9eyN6/EOpT8QFhyYm4dxs6pNQZ+1q3/xyDvVJsH7q
CzrfE0l9EgJU9gl2rwXUJ8HT0VE1OX8R9UlQM+lJNfxi7J8ZmYQs6f//5i/v
VrcT
      "]], LineBox[CompressedData["
1:eJw91HtQlFUYBvBFaqLYYpf7soIsIsgOBCzft7vfZeHhEg7kmFKZheAFdiVB
YTQcQUIsbFOaZYQBBEcnYgoqTK6SjFpZoRiggTrBCBOBSkwUksollCBeemfO
nL/OM793znuOant6nHGZRCJJmF8L++YL9lzOCgaS/2odmJCFYqDoLHqzyCMG
XR3ztZZBfFBh0smiKOwwLRSDubZfB/xCwmG1cCyPgeNrtzQ/hhtQUb5QDGJ/
Pn1zIpRbzGtksPxSGF/wgnYxr4OB6ZXmqprskMW8uwxKVWMtlQnBi3kSFn5K
54+tuMDFPAULLs6c7bnGn3ws9o5/yURd8SMfi2+l1zZqPvMlH4sHudLKW9dW
kY9FrsfKZ+7ovMnHQnvy0/eHerzIx6Kkc/3jrBMq8rGoOpa4acLsST4WXrfv
pzX5riCfFmZPdWRWpjv5tPhBljrYe19Jvvk+vZ5+93ypG/m0uG5zZr3NFgX5
tLjRFzT1TrQr+bSov1ARkRzjQj4tLL2pj79PdiafFqc4yeDDEifyaVH21V+G
832O5Js/P963VR3sSD4dTOkzI2VlDuTTQb67K6lU6kA+HeyTum+OWOzJp0ND
c39jjrs9+XSYfWqdS3KLnHw6RCTsGbseLyefDoFnfnooe05OPh26m11Tj34n
I58OM9Um/twhGfl0SPtHUe8fKyOfHqec0gsPu8nIp4d764uDI8N25NPjXKh8
OqPKjnx6aHZNNooZduTTY9sHPg1PYu3Ip0fV2fLKQyF25NOjqa349Wo/ymvU
49XcPUxKAOV16DE1cnSyO5Ty7upxcWd/qzSR8iQcnvyyZfOGAspTcDj7Vr7/
g7YlHweVoiOrzob6Xcvhz0c9NRaW+jVxuBO/C8ad1G8eB3Z426Xiauq3nMMN
znb0yJiMfBzKU7qi20U5+Th03mv0uVciJx8HhVo+YJmm+5DwyMwXcvJT7MnH
Y1P1uKRmyJ58PHwLvlZPpzqQj8cn+zB7YhnNi4lH3B9D7gM1NC95PELlLTGG
rU7k43Fswnp2t3pp/nhoZmX1bz/rQj4esm5IM+ZcyMej2KoiwcNOQT4BsasO
Kg8IbuQTcNu7UG774dL7EJCxwTlsdGo5+QREzZhrR4s8yCegvXRob3+AJ/kE
yOeuaGwDVOQT0GJz3Gj18tL7nc877aIs/Ggl+QTUZg8//96kN/kE9CdOh48U
+ZBPxP6a5kjTjtXkE9EYnXb184Nq8olQr5BOWP/uTz4RF3u8soWmQPKJMO+v
u/zGAfqv8kS4/t3LTBlDyCdie1JRt3UtSz4Rj0I0fiajnnwi8q33bUxrEMgn
4khcZKblmzDyGaBsn/qizhhBPgMstVd/Ux5/iXwGmC+r+NWtMVCozMFBawz/
/9//AvfBQ/M=
      "]], LineBox[CompressedData["
1:eJwt1G1QVFUcx/FdkBAkXVDBpY0BFoiBUjYErGTu79wDZLhDgjjT8hSRC5NM
gAmC8tCmZSU6YILEKlkY29TwEBKWJA9RlgGJ0NPoCMoLkIUFgQWEUAg85z9z
586dOed75nxeXLek9CithUQi0Sw/K++jqSM1TqECJI8nAte7lkctILuyessl
RzVSkldGwEF78ZfxmJchXVmmExAi1i7t/JFCX74yAtbO+qiSB4Gt/svTIMB3
0O54bGgw63UJeDNO31h/9gXWGxJw7Mhu24zyQH4uEORpMt7ftBV/rCy3Ay4O
bTAWLapYXw746ibdvwnwY/u9AFPaawbX+OfYef7At9Wx4bFNPuA5lOlPKr0z
vFlPDeSs7qeV6V6spwEaE5TOQ9Ue/H7A8+W3tAkuStY7APxW2j0jXHFjPR1A
hi0ve+lcWe8EUFKV3lL6uwu/PxD8apxnUaeC9QzAZEl7Rt+iM/dY/t7b1K+O
l7NeGyBtrr19dsCJ9boA/xerpLs+dGS9m8AzSW/Unw7fyL0Am+nvc5y9N7Ce
GZDL6qptn17P/QhqXwnaMurlwP0I6hYOFZRQe+5H8EFmmNZjv4z7Efzqrjh1
L3Yd9yMwGr+MVkw+yf0Ion1SXfect+N+BNcOxch37l3D/Qha+v59ey7YlvsR
9BpOdhf52HA/gqrm6/5Z3qu5H8EnuXcvBAVacz+Cis9OTRRGPcH9CAYySj12
5FlxP4K/HErKXr+4ivsRNBU6f3zHbMn9CIqzezabBEvuRxB05U+PllIL7kcg
876h+nxayv0INpknosZipdyPwDCcarWuU8L9ROQmqa7mEgn3E3Hc+Oid1Pwl
gfmJeM+c5HD6/UWB+YmoiAu4oC97JDA/EfLiqwdbGx8KzE/ExjSyO6J/QWB+
y/sftC59IVtgPY2Ij87kz7mp/2O9ZBH7qrVhpHie9Q6IKDDUZuXfnmM9nYh+
fd9X8X5zrHdCxLZEacv+wgesVy5CGp7waeTYLOsZRHgqXd46t2eW9RpEvNQx
6DT38wzrtYk4Z8r8TrZthvW6RDzU1s6W1U+z3k0Rait9R4jfNOsNiVA+pbjX
22BmPbMIlTI0zWK7mfUkFHdHtp8puzbFenYUqVlGTYxmivtRbJYX+jmOT3I/
isOZFZ3lxya5H4V1cOKtS+6TwuP/CygcrfJ6SfsE96MYcghrttdOcD8KTY2/
jWTNBPejiBxRtdxIuc/9KEbzGmZ2tY6zno4iS5GzFopx7kfhZu09n1gwxv0o
HLSyVYcHTdyP4p/ulMroSBP3oxhYPxjU/NMo67VR/N2zY/hI4Cj3o+joProv
u26E+1Gcn/K9k/bsCPejqAyY/1qoMXI/itx3bSPaVUbWk4Qgxv0Hdc/lYeF/
lJpQBg==
      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{4., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"Precession Rate (\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SuperscriptBox[\\\"\[Null]\\\", \\\"\[Prime]\[Prime]\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"''\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)/y)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}, {60, 
       FormBox["60", TraditionalForm]}}, None}, {{{10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {30, 
       FormBox["30", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{4., 40.}, {0., 60.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.869290009081172*^9, 3.869292989636064*^9, 
  3.8692932483070107`*^9, 3.869293462801549*^9, 3.8693051154034233`*^9, 
  3.869305201280904*^9, 3.869305341437451*^9, 3.869305420560635*^9, 
  3.8909770834166193`*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"0ef8f6c7-dcf3-4ef3-8add-c1155fbf8f96"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"avalues", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.38710", ",", " ", "0.72333", ",", " ", "1.00002", ",", " ", "1.52364", 
     ",", " ", "5.20248", ",", "\n", "       ", "9.56329", ",", " ", 
     "19.29373", ",", " ", "30.27435"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aouter", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"avalues", ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "8"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pnameout", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<J\>\"", ",", "\"\<S\>\"", ",", "\"\<U\>\"", ",", "\"\<N\>\""}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"paouter", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"aouter", ",", "pnameout"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"linesout", "=", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", "0.004", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "12"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "60"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"60", "-", "2"}]}], "}"}]}], "}"}], "]"}], "&"}], ",", 
        "paouter"}], "]"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{"60", "-", "3"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "&"}], ",", "paouter"}], 
       "]"}]}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ainner", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"avalues", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pnamein", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<M\>\"", ",", "\"\<V\>\"", ",", "\"\<E\>\"", ",", "\"\<M\>\""}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"painner", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"ainner", ",", "pnamein"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"linesin", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", "0.004", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "12"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "60"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"60", "-", "2"}]}], "}"}]}], "}"}], "]"}], "&"}], ",", 
        "painner"}], "]"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{"60", "-", "3"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "&"}], ",", "painner"}], 
       "]"}]}], "}"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8692948802354183`*^9, 3.869294889804311*^9}, 
   3.869294923463685*^9, {3.8692949775852203`*^9, 3.86929499883803*^9}, {
   3.869295191558587*^9, 3.869295218001656*^9}, {3.869295387921208*^9, 
   3.869295388864544*^9}, {3.8692955186307383`*^9, 3.869295545841392*^9}, {
   3.86929624185314*^9, 3.869296245436421*^9}, 3.869296305242774*^9, {
   3.8692991810978823`*^9, 3.869299184394566*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"5c1ae141-d53f-4389-939a-ab23af95e87f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"pout", ",", "linesout"}], "]"}]], "Input",
 CellChangeTimes->{{3.869293468908093*^9, 3.869293500316292*^9}, {
  3.869295098219104*^9, 3.86929512491119*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"cc7f93b0-ab50-42b4-93d4-0a6d195b6c00"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], 
      LineBox[{{0.1, 0.6229797026696402}, {0.2, 2.013032394665853}, {
       0.30000000000000004`, 5.840682433316474}, {0.34234439325543925`, 
       60.}}], LineBox[{{0.4613351220744746, 60.}, {0.5, 
       13.513566773169684`}, {0.6, 34.086553413242996`}, {0.6033928852519468, 
       60.}}], LineBox[{{1.1295847011622868`, 60.}, {1.2000000000000002`, 
       27.441046170569955`}, {1.3000000000000003`, 20.631440575836212`}, {
       1.4000000000000001`, 22.6776053475962}, {1.4263249256150738`, 60.}}], 
      LineBox[{{1.5792350035261062`, 60.}, {1.6, 32.6260347709744}, {
       1.7000000000000002`, 22.734397535729062`}, {1.8000000000000003`, 
       23.08114903542798}, {1.9000000000000001`, 24.80557470428947}, {2., 
       27.101433814777423`}, {2.1, 29.800889402507703`}, {2.2, 
       32.8682711121765}, {2.3000000000000003`, 36.3126483232872}, {
       2.4000000000000004`, 40.16556181640701}, {2.5000000000000004`, 
       44.47455396392125}, {2.6, 49.30194734486096}, {2.7, 
       54.72601436034924}, {2.786208546492953, 60.}}], LineBox[CompressedData["
1:eJw91HlIFGEYx/HdLFOswINy2Q7dXZ09ZmZnZtW0yH5meXSILKVlm5WwRaek
GQqpHVJphJpUJmlrWdmhUS1p0aFFSodakgYVBlq5ZUiH9Edh5tqzPTC8/8x8
5vu+AxOYlm62jpPJZHGjl3N90fC+vfNFMGRjk0ArA/eusulHdiyBaWwYWCMd
N0vk8di4wTkMbB62mN73Mag46RwG3et4e9DkRWh75hwGA+ffscPbo8nTwiOl
qjlRvoA8LU7bj3a33gF5WsRZlMzTsPnkaaH8UFK+W5hHnhaHfAcHc1PnkqfD
OP+oJrfbEeTpkLGtLj5lXjh5OtQOm2dd6wsjT4dPp6t+f6sNJU+Hhos1U2yF
IeTp8dCy7M3dfSby9BgJ9OAaSyXy9Niyqt1rhV0kTw9ZwdJX5xwCeXqI0972
/WYF8gyoqj0r3RvhyTNgZ8D9tZOaOPIMaFYcy7GVs+QZgFs7z+QdNJBnQH3J
iqH+Ij15LN5W/hoyV+vIY9FZ/HW+9bGWPBZJjjUhg3IteSz8WrPzeuMZ8lj0
sxstK22u78zBT9FSUDA+mDwObpbNFQ1ZQeRxUARvmmH5oSGPQ/f6hLah3Rry
OGRkPclU+mjI46HzDvfZc11NHg+Uxqc71qjJ4xH9eeoEwU9NHo/IB8/McV0q
8njURxeVR1SryDPizpnbEzXZKvKMOG6x7YpKUZFnxM+ygMv9sSryjOBD8pMP
R7k8Iy7JA788jHV5AjK8pK2Jq+l+hQDfq8q9M3JVCBnzBZxImaNcVk/PLxWQ
7/HdHV9d7xNQcSXvT/VCNeRObo+A8dkBg9l1rv2MevrC1HBO88+7IUDdNC3x
dYvrvAR0SjuWjOTS+X4U8Cp2SOGfHPzPk4kwVDwvO5XMUJ+IRz0d65cf0FKf
CPOGP/bGAR31iUhL6zflHDVQn4hK9+LVpkMc9YmY3RG6NbPHSH0invuFLfZO
EqlPHO1/mtk20UR9Ioo9eyN6/EOpT8QFhyYm4dxs6pNQZ+1q3/xyDvVJsH7q
CzrfE0l9EgJU9gl2rwXUJ8HT0VE1OX8R9UlQM+lJNfxi7J8ZmYQs6f//5i/v
VrcT
       "]], LineBox[CompressedData["
1:eJw91HtQlFUYBvBFaqLYYpf7soIsIsgOBCzft7vfZeHhEg7kmFKZheAFdiVB
YTQcQUIsbFOaZYQBBEcnYgoqTK6SjFpZoRiggTrBCBOBSkwUksollCBeemfO
nL/OM793znuOant6nHGZRCJJmF8L++YL9lzOCgaS/2odmJCFYqDoLHqzyCMG
XR3ztZZBfFBh0smiKOwwLRSDubZfB/xCwmG1cCyPgeNrtzQ/hhtQUb5QDGJ/
Pn1zIpRbzGtksPxSGF/wgnYxr4OB6ZXmqprskMW8uwxKVWMtlQnBi3kSFn5K
54+tuMDFPAULLs6c7bnGn3ws9o5/yURd8SMfi2+l1zZqPvMlH4sHudLKW9dW
kY9FrsfKZ+7ovMnHQnvy0/eHerzIx6Kkc/3jrBMq8rGoOpa4acLsST4WXrfv
pzX5riCfFmZPdWRWpjv5tPhBljrYe19Jvvk+vZ5+93ypG/m0uG5zZr3NFgX5
tLjRFzT1TrQr+bSov1ARkRzjQj4tLL2pj79PdiafFqc4yeDDEifyaVH21V+G
832O5Js/P963VR3sSD4dTOkzI2VlDuTTQb67K6lU6kA+HeyTum+OWOzJp0ND
c39jjrs9+XSYfWqdS3KLnHw6RCTsGbseLyefDoFnfnooe05OPh26m11Tj34n
I58OM9Um/twhGfl0SPtHUe8fKyOfHqec0gsPu8nIp4d764uDI8N25NPjXKh8
OqPKjnx6aHZNNooZduTTY9sHPg1PYu3Ip0fV2fLKQyF25NOjqa349Wo/ymvU
49XcPUxKAOV16DE1cnSyO5Ty7upxcWd/qzSR8iQcnvyyZfOGAspTcDj7Vr7/
g7YlHweVoiOrzob6Xcvhz0c9NRaW+jVxuBO/C8ad1G8eB3Z426Xiauq3nMMN
znb0yJiMfBzKU7qi20U5+Th03mv0uVciJx8HhVo+YJmm+5DwyMwXcvJT7MnH
Y1P1uKRmyJ58PHwLvlZPpzqQj8cn+zB7YhnNi4lH3B9D7gM1NC95PELlLTGG
rU7k43Fswnp2t3pp/nhoZmX1bz/rQj4esm5IM+ZcyMej2KoiwcNOQT4BsasO
Kg8IbuQTcNu7UG774dL7EJCxwTlsdGo5+QREzZhrR4s8yCegvXRob3+AJ/kE
yOeuaGwDVOQT0GJz3Gj18tL7nc877aIs/Ggl+QTUZg8//96kN/kE9CdOh48U
+ZBPxP6a5kjTjtXkE9EYnXb184Nq8olQr5BOWP/uTz4RF3u8soWmQPKJMO+v
u/zGAfqv8kS4/t3LTBlDyCdie1JRt3UtSz4Rj0I0fiajnnwi8q33bUxrEMgn
4khcZKblmzDyGaBsn/qizhhBPgMstVd/Ux5/iXwGmC+r+NWtMVCozMFBawz/
/9//AvfBQ/M=
       "]], LineBox[CompressedData["
1:eJwt1G1QVFUcx/FdkBAkXVDBpY0BFoiBUjYErGTu79wDZLhDgjjT8hSRC5NM
gAmC8tCmZSU6YILEKlkY29TwEBKWJA9RlgGJ0NPoCMoLkIUFgQWEUAg85z9z
586dOed75nxeXLek9CithUQi0Sw/K++jqSM1TqECJI8nAte7lkctILuyessl
RzVSkldGwEF78ZfxmJchXVmmExAi1i7t/JFCX74yAtbO+qiSB4Gt/svTIMB3
0O54bGgw63UJeDNO31h/9gXWGxJw7Mhu24zyQH4uEORpMt7ftBV/rCy3Ay4O
bTAWLapYXw746ibdvwnwY/u9AFPaawbX+OfYef7At9Wx4bFNPuA5lOlPKr0z
vFlPDeSs7qeV6V6spwEaE5TOQ9Ue/H7A8+W3tAkuStY7APxW2j0jXHFjPR1A
hi0ve+lcWe8EUFKV3lL6uwu/PxD8apxnUaeC9QzAZEl7Rt+iM/dY/t7b1K+O
l7NeGyBtrr19dsCJ9boA/xerpLs+dGS9m8AzSW/Unw7fyL0Am+nvc5y9N7Ce
GZDL6qptn17P/QhqXwnaMurlwP0I6hYOFZRQe+5H8EFmmNZjv4z7Efzqrjh1
L3Yd9yMwGr+MVkw+yf0Ion1SXfect+N+BNcOxch37l3D/Qha+v59ey7YlvsR
9BpOdhf52HA/gqrm6/5Z3qu5H8EnuXcvBAVacz+Cis9OTRRGPcH9CAYySj12
5FlxP4K/HErKXr+4ivsRNBU6f3zHbMn9CIqzezabBEvuRxB05U+PllIL7kcg
876h+nxayv0INpknosZipdyPwDCcarWuU8L9ROQmqa7mEgn3E3Hc+Oid1Pwl
gfmJeM+c5HD6/UWB+YmoiAu4oC97JDA/EfLiqwdbGx8KzE/ExjSyO6J/QWB+
y/sftC59IVtgPY2Ij87kz7mp/2O9ZBH7qrVhpHie9Q6IKDDUZuXfnmM9nYh+
fd9X8X5zrHdCxLZEacv+wgesVy5CGp7waeTYLOsZRHgqXd46t2eW9RpEvNQx
6DT38wzrtYk4Z8r8TrZthvW6RDzU1s6W1U+z3k0Rait9R4jfNOsNiVA+pbjX
22BmPbMIlTI0zWK7mfUkFHdHtp8puzbFenYUqVlGTYxmivtRbJYX+jmOT3I/
isOZFZ3lxya5H4V1cOKtS+6TwuP/CygcrfJ6SfsE96MYcghrttdOcD8KTY2/
jWTNBPejiBxRtdxIuc/9KEbzGmZ2tY6zno4iS5GzFopx7kfhZu09n1gwxv0o
HLSyVYcHTdyP4p/ulMroSBP3oxhYPxjU/NMo67VR/N2zY/hI4Cj3o+joProv
u26E+1Gcn/K9k/bsCPejqAyY/1qoMXI/itx3bSPaVUbWk4Qgxv0Hdc/lYeF/
lJpQBg==
       "]]}}, {{}, {}}}, 
   {Thickness[0.004], 
    StyleBox[{{LineBox[{{5.20248, 60}, {5.20248, 58}}], 
       LineBox[{{9.56329, 60}, {9.56329, 58}}], 
       LineBox[{{19.29373, 60}, {19.29373, 58}}], 
       LineBox[{{30.27435, 60}, {30.27435, 58}}]}, {
       InsetBox["\<\"J\"\>", {5.20248, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"S\"\>", {9.56329, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"U\"\>", {19.29373, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"N\"\>", {30.27435, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]]}},
     FontFamily->"Times",
     FontSize->12]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{4., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"Precession Rate (\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SuperscriptBox[\\\"\[Null]\\\", \\\"\[Prime]\[Prime]\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"''\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)/y)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}, {60, 
       FormBox["60", TraditionalForm]}}, None}, {{{10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {30, 
       FormBox["30", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{4., 40.}, {0., 60.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.8692934788697357`*^9, 3.869293500870205*^9}, 
   3.869294940019176*^9, {3.8692949847569923`*^9, 3.869295004265663*^9}, {
   3.869295105211635*^9, 3.869295128082838*^9}, 3.869295405642214*^9, 
   3.869299189405374*^9, 3.869305115449254*^9, 3.8693052013299637`*^9, 
   3.8693053414765463`*^9, 3.869305420593253*^9, 3.8909770834541903`*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"6e27b18a-4d24-472a-9dfe-c4d75dbd5831"]
}, Open  ]],

Cell["\<\
Create a graphics object of lines denoting the secular eigenfrequencies.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b807715f-59bb-4418-ba6a-d9752e9c790e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gout", " ", "=", " ", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"4", ",", "#"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"40", ",", "#"}], "}"}]}], "}"}], "]"}], "&"}], ",", " ", 
      "gg"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fout", " ", "=", " ", 
   RowBox[{"Graphics", "[", "\n", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Dashing", "[", 
        RowBox[{"{", 
         RowBox[{"0.01", ",", " ", "0.01"}], "}"}], "]"}], "}"}], ",", "\n", 
      "     ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4", ",", "#"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"40", ",", "#"}], "}"}]}], "}"}], "]"}], "&"}], ",", " ", 
        RowBox[{"-", "ff"}]}], "]"}]}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8692900435410833`*^9, 3.869290043546014*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"c3f238e3-d7bf-4aec-b4ac-7e2a5eef3131"],

Cell["\<\
Display the plot with the eigenfrequencies.    This is Fig.7.12b.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869305067147843*^9, 3.869305071257723*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"55fb4b69-e04b-43fe-9a16-642eea83637e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"pout", ",", " ", "gout", ",", " ", "fout", ",", "linesout"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8692900556292763`*^9, 3.86929005563697*^9}, {
   3.869292947969159*^9, 3.869292949978672*^9}, {3.869293017751717*^9, 
   3.869293059823992*^9}, 3.869293263496649*^9, {3.869293323226323*^9, 
   3.8692933291661158`*^9}, {3.869293397944632*^9, 3.869293400567275*^9}, {
   3.869295142043618*^9, 3.869295145462634*^9}, 3.869295423604617*^9},
 CellLabel->"In[43]:=",ExpressionUUID->"b32715c9-6564-4546-a66c-ebee4557067e"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], 
      LineBox[{{0.1, 0.6229797026696402}, {0.2, 2.013032394665853}, {
       0.30000000000000004`, 5.840682433316474}, {0.34234439325543925`, 
       60.}}], LineBox[{{0.4613351220744746, 60.}, {0.5, 
       13.513566773169684`}, {0.6, 34.086553413242996`}, {0.6033928852519468, 
       60.}}], LineBox[{{1.1295847011622868`, 60.}, {1.2000000000000002`, 
       27.441046170569955`}, {1.3000000000000003`, 20.631440575836212`}, {
       1.4000000000000001`, 22.6776053475962}, {1.4263249256150738`, 60.}}], 
      LineBox[{{1.5792350035261062`, 60.}, {1.6, 32.6260347709744}, {
       1.7000000000000002`, 22.734397535729062`}, {1.8000000000000003`, 
       23.08114903542798}, {1.9000000000000001`, 24.80557470428947}, {2., 
       27.101433814777423`}, {2.1, 29.800889402507703`}, {2.2, 
       32.8682711121765}, {2.3000000000000003`, 36.3126483232872}, {
       2.4000000000000004`, 40.16556181640701}, {2.5000000000000004`, 
       44.47455396392125}, {2.6, 49.30194734486096}, {2.7, 
       54.72601436034924}, {2.786208546492953, 60.}}], LineBox[CompressedData["
1:eJw91HlIFGEYx/HdLFOswINy2Q7dXZ09ZmZnZtW0yH5meXSILKVlm5WwRaek
GQqpHVJphJpUJmlrWdmhUS1p0aFFSodakgYVBlq5ZUiH9Edh5tqzPTC8/8x8
5vu+AxOYlm62jpPJZHGjl3N90fC+vfNFMGRjk0ArA/eusulHdiyBaWwYWCMd
N0vk8di4wTkMbB62mN73Mag46RwG3et4e9DkRWh75hwGA+ffscPbo8nTwiOl
qjlRvoA8LU7bj3a33gF5WsRZlMzTsPnkaaH8UFK+W5hHnhaHfAcHc1PnkqfD
OP+oJrfbEeTpkLGtLj5lXjh5OtQOm2dd6wsjT4dPp6t+f6sNJU+Hhos1U2yF
IeTp8dCy7M3dfSby9BgJ9OAaSyXy9Niyqt1rhV0kTw9ZwdJX5xwCeXqI0972
/WYF8gyoqj0r3RvhyTNgZ8D9tZOaOPIMaFYcy7GVs+QZgFs7z+QdNJBnQH3J
iqH+Ij15LN5W/hoyV+vIY9FZ/HW+9bGWPBZJjjUhg3IteSz8WrPzeuMZ8lj0
sxstK22u78zBT9FSUDA+mDwObpbNFQ1ZQeRxUARvmmH5oSGPQ/f6hLah3Rry
OGRkPclU+mjI46HzDvfZc11NHg+Uxqc71qjJ4xH9eeoEwU9NHo/IB8/McV0q
8njURxeVR1SryDPizpnbEzXZKvKMOG6x7YpKUZFnxM+ygMv9sSryjOBD8pMP
R7k8Iy7JA788jHV5AjK8pK2Jq+l+hQDfq8q9M3JVCBnzBZxImaNcVk/PLxWQ
7/HdHV9d7xNQcSXvT/VCNeRObo+A8dkBg9l1rv2MevrC1HBO88+7IUDdNC3x
dYvrvAR0SjuWjOTS+X4U8Cp2SOGfHPzPk4kwVDwvO5XMUJ+IRz0d65cf0FKf
CPOGP/bGAR31iUhL6zflHDVQn4hK9+LVpkMc9YmY3RG6NbPHSH0invuFLfZO
EqlPHO1/mtk20UR9Ioo9eyN6/EOpT8QFhyYm4dxs6pNQZ+1q3/xyDvVJsH7q
CzrfE0l9EgJU9gl2rwXUJ8HT0VE1OX8R9UlQM+lJNfxi7J8ZmYQs6f//5i/v
VrcT
       "]], LineBox[CompressedData["
1:eJw91HtQlFUYBvBFaqLYYpf7soIsIsgOBCzft7vfZeHhEg7kmFKZheAFdiVB
YTQcQUIsbFOaZYQBBEcnYgoqTK6SjFpZoRiggTrBCBOBSkwUksollCBeemfO
nL/OM793znuOant6nHGZRCJJmF8L++YL9lzOCgaS/2odmJCFYqDoLHqzyCMG
XR3ztZZBfFBh0smiKOwwLRSDubZfB/xCwmG1cCyPgeNrtzQ/hhtQUb5QDGJ/
Pn1zIpRbzGtksPxSGF/wgnYxr4OB6ZXmqprskMW8uwxKVWMtlQnBi3kSFn5K
54+tuMDFPAULLs6c7bnGn3ws9o5/yURd8SMfi2+l1zZqPvMlH4sHudLKW9dW
kY9FrsfKZ+7ovMnHQnvy0/eHerzIx6Kkc/3jrBMq8rGoOpa4acLsST4WXrfv
pzX5riCfFmZPdWRWpjv5tPhBljrYe19Jvvk+vZ5+93ypG/m0uG5zZr3NFgX5
tLjRFzT1TrQr+bSov1ARkRzjQj4tLL2pj79PdiafFqc4yeDDEifyaVH21V+G
832O5Js/P963VR3sSD4dTOkzI2VlDuTTQb67K6lU6kA+HeyTum+OWOzJp0ND
c39jjrs9+XSYfWqdS3KLnHw6RCTsGbseLyefDoFnfnooe05OPh26m11Tj34n
I58OM9Um/twhGfl0SPtHUe8fKyOfHqec0gsPu8nIp4d764uDI8N25NPjXKh8
OqPKjnx6aHZNNooZduTTY9sHPg1PYu3Ip0fV2fLKQyF25NOjqa349Wo/ymvU
49XcPUxKAOV16DE1cnSyO5Ty7upxcWd/qzSR8iQcnvyyZfOGAspTcDj7Vr7/
g7YlHweVoiOrzob6Xcvhz0c9NRaW+jVxuBO/C8ad1G8eB3Z426Xiauq3nMMN
znb0yJiMfBzKU7qi20U5+Th03mv0uVciJx8HhVo+YJmm+5DwyMwXcvJT7MnH
Y1P1uKRmyJ58PHwLvlZPpzqQj8cn+zB7YhnNi4lH3B9D7gM1NC95PELlLTGG
rU7k43Fswnp2t3pp/nhoZmX1bz/rQj4esm5IM+ZcyMej2KoiwcNOQT4BsasO
Kg8IbuQTcNu7UG774dL7EJCxwTlsdGo5+QREzZhrR4s8yCegvXRob3+AJ/kE
yOeuaGwDVOQT0GJz3Gj18tL7nc877aIs/Ggl+QTUZg8//96kN/kE9CdOh48U
+ZBPxP6a5kjTjtXkE9EYnXb184Nq8olQr5BOWP/uTz4RF3u8soWmQPKJMO+v
u/zGAfqv8kS4/t3LTBlDyCdie1JRt3UtSz4Rj0I0fiajnnwi8q33bUxrEMgn
4khcZKblmzDyGaBsn/qizhhBPgMstVd/Ux5/iXwGmC+r+NWtMVCozMFBawz/
/9//AvfBQ/M=
       "]], LineBox[CompressedData["
1:eJwt1G1QVFUcx/FdkBAkXVDBpY0BFoiBUjYErGTu79wDZLhDgjjT8hSRC5NM
gAmC8tCmZSU6YILEKlkY29TwEBKWJA9RlgGJ0NPoCMoLkIUFgQWEUAg85z9z
586dOed75nxeXLek9CithUQi0Sw/K++jqSM1TqECJI8nAte7lkctILuyessl
RzVSkldGwEF78ZfxmJchXVmmExAi1i7t/JFCX74yAtbO+qiSB4Gt/svTIMB3
0O54bGgw63UJeDNO31h/9gXWGxJw7Mhu24zyQH4uEORpMt7ftBV/rCy3Ay4O
bTAWLapYXw746ibdvwnwY/u9AFPaawbX+OfYef7At9Wx4bFNPuA5lOlPKr0z
vFlPDeSs7qeV6V6spwEaE5TOQ9Ue/H7A8+W3tAkuStY7APxW2j0jXHFjPR1A
hi0ve+lcWe8EUFKV3lL6uwu/PxD8apxnUaeC9QzAZEl7Rt+iM/dY/t7b1K+O
l7NeGyBtrr19dsCJ9boA/xerpLs+dGS9m8AzSW/Unw7fyL0Am+nvc5y9N7Ce
GZDL6qptn17P/QhqXwnaMurlwP0I6hYOFZRQe+5H8EFmmNZjv4z7Efzqrjh1
L3Yd9yMwGr+MVkw+yf0Ion1SXfect+N+BNcOxch37l3D/Qha+v59ey7YlvsR
9BpOdhf52HA/gqrm6/5Z3qu5H8EnuXcvBAVacz+Cis9OTRRGPcH9CAYySj12
5FlxP4K/HErKXr+4ivsRNBU6f3zHbMn9CIqzezabBEvuRxB05U+PllIL7kcg
876h+nxayv0INpknosZipdyPwDCcarWuU8L9ROQmqa7mEgn3E3Hc+Oid1Pwl
gfmJeM+c5HD6/UWB+YmoiAu4oC97JDA/EfLiqwdbGx8KzE/ExjSyO6J/QWB+
y/sftC59IVtgPY2Ij87kz7mp/2O9ZBH7qrVhpHie9Q6IKDDUZuXfnmM9nYh+
fd9X8X5zrHdCxLZEacv+wgesVy5CGp7waeTYLOsZRHgqXd46t2eW9RpEvNQx
6DT38wzrtYk4Z8r8TrZthvW6RDzU1s6W1U+z3k0Rait9R4jfNOsNiVA+pbjX
22BmPbMIlTI0zWK7mfUkFHdHtp8puzbFenYUqVlGTYxmivtRbJYX+jmOT3I/
isOZFZ3lxya5H4V1cOKtS+6TwuP/CygcrfJ6SfsE96MYcghrttdOcD8KTY2/
jWTNBPejiBxRtdxIuc/9KEbzGmZ2tY6zno4iS5GzFopx7kfhZu09n1gwxv0o
HLSyVYcHTdyP4p/ulMroSBP3oxhYPxjU/NMo67VR/N2zY/hI4Cj3o+joProv
u26E+1Gcn/K9k/bsCPejqAyY/1qoMXI/itx3bSPaVUbWk4Qgxv0Hdc/lYeF/
lJpQBg==
       "]]}}, {{}, {}}}, {LineBox[{{4, 5.46326}, {40, 5.46326}}], 
    LineBox[{{4, 7.34474}, {40, 7.34474}}], 
    LineBox[{{4, 17.32832}, {40, 17.32832}}], 
    LineBox[{{4, 18.00233}, {40, 18.00233}}], 
    LineBox[{{4, 4.29591}, {40, 4.29591}}], 
    LineBox[{{4, 27.77406}, {40, 27.77406}}], 
    LineBox[{{4, 2.71931}, {40, 2.71931}}], 
    LineBox[{{4, 0.63332}, {40, 0.63332}}], 
    LineBox[{{4, -19.18225}, {40, -19.18225}}], 
    LineBox[{{4, 51.25222}, {40, 51.25222}}]}, 
   {Dashing[{0.01, 0.01}], LineBox[{{4, 5.21054}, {40, 5.21054}}], 
    LineBox[{{4, 6.5708}, {40, 6.5708}}], 
    LineBox[{{4, 18.74359}, {40, 18.74359}}], 
    LineBox[{{4, 17.63331}, {40, 17.63331}}], LineBox[{{4, 0.}, {40, 0.}}], 
    LineBox[{{4, 25.73355}, {40, 25.73355}}], 
    LineBox[{{4, 2.90266}, {40, 2.90266}}], 
    LineBox[{{4, 0.67752}, {40, 0.67752}}]}, 
   {Thickness[0.004], 
    StyleBox[{{LineBox[{{5.20248, 60}, {5.20248, 58}}], 
       LineBox[{{9.56329, 60}, {9.56329, 58}}], 
       LineBox[{{19.29373, 60}, {19.29373, 58}}], 
       LineBox[{{30.27435, 60}, {30.27435, 58}}]}, {
       InsetBox["\<\"J\"\>", {5.20248, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"S\"\>", {9.56329, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"U\"\>", {19.29373, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]], 
       InsetBox["\<\"N\"\>", {30.27435, 57}, NCache[
        ImageScaled[{Rational[1, 2], 1}], ImageScaled[{0.5, 1}]]]}},
     FontFamily->"Times",
     FontSize->12]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{4., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"Precession Rate (\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SuperscriptBox[\\\"\[Null]\\\", \\\"\[Prime]\[Prime]\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"''\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)/y)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Semi-major Axis (AU)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}, {60, 
       FormBox["60", TraditionalForm]}}, None}, {{{10, 
       FormBox["10", TraditionalForm]}, {20, 
       FormBox["20", TraditionalForm]}, {30, 
       FormBox["30", TraditionalForm]}, {40, 
       FormBox["40", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{4., 40.}, {0., 60.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.869290056256782*^9, 3.8692929507983437`*^9, {3.869293007812354*^9, 
   3.869293025554182*^9}, 3.869293060868322*^9, 3.869293264582595*^9, 
   3.86929333018452*^9, 3.869293401427685*^9, 3.869295147464028*^9, {
   3.869295416206121*^9, 3.869295424543939*^9}, 3.869299195806591*^9, 
   3.8693051154913483`*^9, 3.869305201385901*^9, 3.8693053415161867`*^9, 
   3.869305420626223*^9, 3.890977083496543*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"e65d2c84-35a1-4b74-a340-8cccff574007"]
}, Open  ]]
},
WindowToolbars->"MultipurposeBar",
CellGrouping->Manual,
WindowSize->{1026, 663},
WindowMargins->{{80, Automatic}, {Automatic, 27}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"b0eb7993-f1d2-410f-9b1f-451674d9e365"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"442974ec-4c9e-45c9-ba2e-af4f9ea01dbf"],
Cell[1000, 31, 180, 3, 67, "Section",ExpressionUUID->"4c583ca5-29ab-42df-b722-130c8619e95e"],
Cell[1183, 36, 291, 8, 49, "Text",ExpressionUUID->"23a1f66f-3303-412c-995e-0cd8bd4183f4"],
Cell[1477, 46, 1134, 31, 73, "Input",ExpressionUUID->"109a3ed6-d326-45f6-9afe-a78fe02017d1"],
Cell[2614, 79, 477, 14, 76, "Text",ExpressionUUID->"2b3480b4-09f3-4ff8-ab9e-88093ccdc961"],
Cell[3094, 95, 4268, 104, 493, "Input",ExpressionUUID->"2989f186-9c3a-43ae-99a0-2a1ab1b17c59"],
Cell[7365, 201, 205, 5, 53, "Text",ExpressionUUID->"833daf2b-3d5a-4992-91e2-b97366f85591"],
Cell[7573, 208, 945, 23, 94, "Input",ExpressionUUID->"289382b8-ccb6-4ca0-9300-e3b8a56a0ced"],
Cell[8521, 233, 289, 5, 53, "Text",ExpressionUUID->"f62e59a8-5418-412b-a8ad-c0d1bc27f02c"],
Cell[8813, 240, 4649, 129, 325, "Input",ExpressionUUID->"0c55eb8d-daaf-4c66-984c-7c9a6e23e2fb"],
Cell[13465, 371, 562, 12, 53, "Input",ExpressionUUID->"f2b78f0b-e3bd-4a65-9648-dcf6de6a2893"],
Cell[14030, 385, 368, 8, 53, "Text",ExpressionUUID->"faf53744-1524-4491-862a-40ad8ebaf6ed"],
Cell[14401, 395, 493, 11, 52, "Input",ExpressionUUID->"e6fddd57-b9ce-462e-af5b-bb1ea51d7d85"],
Cell[14897, 408, 173, 3, 53, "Text",ExpressionUUID->"40d611ae-cfdb-440a-8da0-66352d0283e2"],
Cell[CellGroupData[{
Cell[15095, 415, 1728, 44, 115, "Input",ExpressionUUID->"21e982c4-4262-4ab0-8239-60d9a14424a1"],
Cell[16826, 461, 8483, 181, 261, "Output",ExpressionUUID->"3366f7a3-da4b-4942-bda7-0aaa6ab1a3c6"]
}, Open  ]],
Cell[25324, 645, 206, 5, 53, "Text",ExpressionUUID->"ba5135e1-2c59-491a-aa78-65a25046a98e"],
Cell[25533, 652, 1259, 38, 94, "Input",ExpressionUUID->"503000d8-08fc-4e54-a893-1eb454f569cf"],
Cell[26795, 692, 169, 3, 53, "Text",ExpressionUUID->"c8e91a1b-2259-40cb-816b-efcaf106f07e"],
Cell[CellGroupData[{
Cell[26989, 699, 258, 4, 30, "Input",ExpressionUUID->"c4b21143-d0dd-4903-8a8a-e01274524869"],
Cell[27250, 705, 9956, 211, 261, "Output",ExpressionUUID->"5b545147-49d5-44f5-8169-0845254e1c64"],
Cell[37209, 918, 7843, 159, 260, "Output",ExpressionUUID->"d8630a45-cac7-41e9-a98f-617ed399a1df"]
}, Open  ]],
Cell[45067, 1080, 420, 9, 76, "Text",ExpressionUUID->"f552633e-c63f-401a-afa2-a8f056d9249a"],
Cell[45490, 1091, 840, 20, 30, "Input",ExpressionUUID->"71d1e334-7049-4144-acde-527a1eeb4c2f"],
Cell[46333, 1113, 274, 5, 53, "Text",ExpressionUUID->"11b613ed-152d-43ad-b2c7-a3919834cafa"],
Cell[46610, 1120, 559, 15, 52, "Input",ExpressionUUID->"07e27dcc-5021-47b0-8e84-b1b02c1c7a9e"],
Cell[47172, 1137, 227, 4, 53, "Text",ExpressionUUID->"868f759c-230a-49b1-b3e7-c701b89eadd6"],
Cell[47402, 1143, 317, 6, 30, "Input",ExpressionUUID->"daf29881-2698-4069-a662-e4989c4e9250"],
Cell[47722, 1151, 283, 5, 53, "Text",ExpressionUUID->"72b4a39d-91e3-4a97-8341-4b277a76cb16"],
Cell[48008, 1158, 509, 14, 30, "Input",ExpressionUUID->"07a66928-5da8-40ce-8cc6-882dc01946ad"],
Cell[48520, 1174, 335, 8, 53, "Text",ExpressionUUID->"e5f464da-3f97-437e-9bdd-8df3e606eb4e"],
Cell[48858, 1184, 661, 15, 30, "Input",ExpressionUUID->"cc9ead3e-0f3a-43ef-b5a4-676688f68977"],
Cell[49522, 1201, 289, 5, 53, "Text",ExpressionUUID->"f6f8f764-8dbb-49b7-a151-4d281ab1317f"],
Cell[49814, 1208, 661, 16, 30, "Input",ExpressionUUID->"2db8e010-878e-40c7-955b-c5d25deb53ef"],
Cell[50478, 1226, 334, 6, 53, "Text",ExpressionUUID->"16f02588-cf93-4678-82aa-ce490650ba17"],
Cell[CellGroupData[{
Cell[50837, 1236, 276, 5, 30, "Input",ExpressionUUID->"8adbb41c-def6-4f64-b1fe-c8b3d764c034"],
Cell[51116, 1243, 10262, 216, 261, "Output",ExpressionUUID->"c29d2d6c-759d-4252-aa8c-57af304fc382"]
}, Open  ]],
Cell[61393, 1462, 325, 7, 53, "Text",ExpressionUUID->"42a8c10d-d498-4489-8574-9571b678f5d6"],
Cell[61721, 1471, 491, 11, 52, "Input",ExpressionUUID->"8d89b40e-6ccd-441e-82ca-a8e66af8c8eb"],
Cell[62215, 1484, 176, 3, 53, "Text",ExpressionUUID->"ea41f3db-d17e-4ca9-9c9d-4b458e80023d"],
Cell[CellGroupData[{
Cell[62416, 1491, 1546, 41, 115, "Input",ExpressionUUID->"a0f1333b-c163-46d2-bf68-83a345a20e98"],
Cell[63965, 1534, 9389, 194, 259, "Output",ExpressionUUID->"0ef8f6c7-dcf3-4ef3-8add-c1155fbf8f96"]
}, Open  ]],
Cell[73369, 1731, 4650, 129, 325, "Input",ExpressionUUID->"5c1ae141-d53f-4389-939a-ab23af95e87f"],
Cell[CellGroupData[{
Cell[78044, 1864, 283, 5, 30, "Input",ExpressionUUID->"cc7f93b0-ab50-42b4-93d4-0a6d195b6c00"],
Cell[78330, 1871, 10303, 209, 259, "Output",ExpressionUUID->"6e27b18a-4d24-472a-9dfe-c4d75dbd5831"]
}, Open  ]],
Cell[88648, 2083, 206, 5, 53, "Text",ExpressionUUID->"b807715f-59bb-4418-ba6a-d9752e9c790e"],
Cell[88857, 2090, 1255, 37, 94, "Input",ExpressionUUID->"c3f238e3-d7bf-4aec-b4ac-7e2a5eef3131"],
Cell[90115, 2129, 265, 6, 53, "Text",ExpressionUUID->"55fb4b69-e04b-43fe-9a16-642eea83637e"],
Cell[CellGroupData[{
Cell[90405, 2139, 567, 9, 30, "Input",ExpressionUUID->"b32715c9-6564-4546-a66c-ebee4557067e"],
Cell[90975, 2150, 11201, 227, 282, "Output",ExpressionUUID->"e65d2c84-35a1-4b74-a340-8cccff574007"]
}, Open  ]]
}
]
*)

